;----------------------------------------------------------------
; Credits
;----------------------------------------------------------------
;Game: Bram Stoker's Dracula
;Original Code: Jeroen Tel
;Music Composition: Jeroen Tel
;Music driver conversion to ASM6 format.
;Conversion by Gil-Galad 08/04/2010
;PROBE SOFTWARE NINTENDO FAMICOM MUSIC-DRIVER
;Copyright 1991 by PROBE SOFTWARE LIMITED
;All rights reserved. For use under license only. 

;----------------------------------------------------------------
; Notes
;----------------------------------------------------------------

;	! ! !	P A L     V E R S I O N     ! ! !

; SEE 'DRACULAN.NIN' FOR A NOTE TO DARYL.... ...VAN HORN...

; GAME: BRAM STOKER'S DRACULA (NES) DATE: 21-11-1992  VERSION: PAL
;
; FOR : PROBE SOFTWARE LIMITED
;
; MUSIC COMPOSED AND SOUNDEFFECTS CREATED BY: JEROEN TEL / THE SONIC CIRCLE

;---------------------------------------------------------------- 
; iNES Header Constants 
;---------------------------------------------------------------- 

PRG_COUNT = 1 ;1 = 16KB, 2 = 32KB 
MIRRORING = %0001 ;%0000 = horizontal, %0001 = vertical, %1000 = four-screen

;---------------------------------------------------------------- 
; iNES header 
;---------------------------------------------------------------- 

   .db "NES", $1a ;identification of the iNES header 
   .db PRG_COUNT ;number of 16KB PRG-ROM pages 
   .db $00 ;number of 8KB CHR-ROM pages 
   .db $00|MIRRORING ;mapper 0 and mirroring
   .dsb 9, $00 ;clear the remaining bytes 

;---------------------------------------------------------------- 
; Interrupt Setup Variables
;----------------------------------------------------------------

PCR0    	=	$2000	;PPU 	CONTROL REGISTER 1
PCR1    	=	$2001	;PPU 	CONTROL REGISTER 2
PSTR    	=	$2002	;	STATUS REGISTER
DMACNT  	=	$2003	;	DMA PAGE COUNT
PSOR    	=	$2005	;	SCROLL OFFSET REGISTER
PMAR    	=	$2006	;	MEMORY ADDRESS REGISTER
PMDR    	=	$2007	;	MEMORY DATA REGISTER
JOY1PORT	=	$4016	;JOYSTICK PORT 1
JOY2PORT	=	$4017	;JOYSTICK PORT 2

JOY1LAST	=	$04
JOY1DATA	=	$05
JOY1DELAY	=	$06
JOY1EDGE	=	$07

AA	        =	$08
RUNFLAG	        =	$09

SFXCOUNT	=	$0A
SFXDELAY	=	$0B
;PALCONVI	=	$0C

JOYBUTA	        =	%10000000
JOYBUTB	        =	%01000000
JOYSELECT	=	%00100000
JOYSTART	=	%00010000
JOYUP	        =	%00001000
JOYDOWN	        =	%00000100
JOYLEFT	        =	%00000010
JOYRIGHT	=	%00000001


;---------------------------------------------------------------- 
; Interrupt and Initialization Code - Joypad Control
;---------------------------------------------------------------- 

.org $C000

RESETVECTOR	
        SEI
	LDA	#0
	STA	PCR0	;INIT THE CONTROL REGISTERS
	STA	PCR1

AJOHNNY	LDA	PSTR	;WAIT FOR HARDWARE TO STABILISE.
	BPL	AJOHNNY
BJOHNNY	LDA	PSTR
	BPL	BJOHNNY
CJOHNNY	LDA	PSTR
	BMI	CJOHNNY

	
	LDX	#$FF
	TXS

	LDX	#$00
	TXA
CLEARMEM
        STA	$0000,X
	STA	$0100,X
	STA	$0200,X
	STA	$0300,X
	STA	$0400,X
	STA	$0500,X
	STA	$0600,X
	STA	$0700,X
	INX
	BNE	CLEARMEM

	JSR	AUDIOCL
      
	LDA	#INITVAL0
	LDX	#$00
	JSR 	AUDIOIN
       	LDA	#INITVAL1
       	LDX	#$01
       	JSR	AUDIOIN
	LDA	#INITVAL2
	LDX	#$02
	JSR	AUDIOIN
	LDA	#INITVAL3
	LDX	#$03
	JSR	AUDIOIN 

	LDA	#$00
	STA	SFXCOUNT
;       STA	PALCONVI

	LDA	#$80	;ENABLE NMI'S
	STA	PCR0




	;WAIT FOR FLAG TO BE SET BY NMI

PROCESSOR	
        LDA	RUNFLAG  
	BEQ	PROCESSOR
	LDA	#0       
	STA	RUNFLAG

	LDX	#$10;6
	LDY	#$00
DLY	DEY
	BNE	DLY
	DEX
	BNE	DLY


	LDA	#$00	;SET TINT
       	STA	PCR1

;             DEC	PALCONVI
;             BPL	NOPROBLEMO
;             LDA	#$05
;             STA	PALCONVI
;             JMP	NOPLAY		
;NOPROBLEMO   
	LDX	#$00
       	JSR	AUDIOPL	;PLAY AUDIO-ROUTINE
        LDX	#$01
        JSR	AUDIOPL
       	LDX	#$02
       	JSR	AUDIOPL
       	LDX	#$03
       	JSR	AUDIOPL
NOPLAY
        JSR	READJOY
	JSR	DOCOMS

	LDA	#$80
	STA	PCR1
        JMP	PROCESSOR

NMI	STA	AA

     	LDA	#1
     	STA	RUNFLAG

	LDA	AA
IRQ	RTI



READJOY	LDY	#1
	STY	JOY1PORT
	DEY
	STY	JOY1PORT

	LDY	#8	;NUMBER OF BITS TO READ.
READJ1	PHA
	LDA	JOY1PORT
	STA	JOY1LAST
	LSR	A	
 	ORA	JOY1LAST
	LSR	A	
	PLA
	ROL	A	
	DEY
	BNE	READJ1

	LDY	JOY1DATA
	STY	JOY1LAST
	STA	JOY1DATA
	EOR	JOY1LAST
	AND	JOY1DATA
	STA	JOY1EDGE
	LDY	#$10
	LDA	JOY1DATA
	CMP	JOY1LAST
	BNE	READJ2
	DEC	JOY1DELAY
	BNE	READJ3
	STA	JOY1EDGE
	LDY	#12
READJ2	STY	JOY1DELAY
READJ3	RTS

DOCOMS	LDA	JOY1DATA
   	AND	#JOYBUTA
   	BEQ	SKIP
	
	LDX	#$00
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	LDX	#$01
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	LDX	#$02
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	LDX	#$03
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL
	JSR	AUDIOPL

SKIP	LDA	JOY1DATA
   	AND	#JOYBUTB
	BEQ	HOND
	DEC	SFXDELAY
	BPL	HOND
	LDA	#$07
	STA	SFXDELAY
	INC	SFXCOUNT
HEMDAAR	LDY	SFXCOUNT
	LDA	SFXTAB0,Y
	LDX	#$00
	JSR	AUDIOIN
	LDA	SFXTAB1,Y
	LDX	#$01
	JSR	AUDIOIN
	LDA	SFXTAB2,Y
	LDX	#$02
	JSR	AUDIOIN
	LDA	SFXTAB3,Y
	LDX	#$03
	JSR	AUDIOIN
	RTS

HOND	LDA	JOY1DATA
	AND	#JOYSTART
	BEQ	HOND1
	JMP	HEMDAAR
HOND1	RTS

;----------------------------------------------------------------
;Music Driver Source Code Header
;----------------------------------------------------------------

;TYPE: INGAME AUDIO
;BY:   JEROEN TEL
;FORMAT: NES (NINTENDO 8-bit)
;GAME: Bram Stoker's Dracula
;FOR: PROBE SOFTWARE LTD / OCEAN SOFTWARE LIMITED
;DATE: 11/92

;----------------------------------------------------------------
; Music Driver Variables
;----------------------------------------------------------------

SSSLO	=	$FE	
SSSHI	=	$FF	

.enum $0400

ENABWORD .dsb 00
VOICTEST .dsb 01
STPINDEX .dsb 04
SEQINDEX .dsb 04
SEQPOSIT .dsb 04
STEPNUMB .dsb 04
SPDCOUNT .dsb 04
SPDINDEX .dsb 04
REALPLAY .dsb 04
NOTEINIT .dsb 04
REALSOUN .dsb 04
LENGCOPY .dsb 04
NOTELENG .dsb 04
REALNOTE .dsb 04
LOFRQWRD .dsb 04
HIFRQWRD .dsb 04
TRANBYTE .dsb 04
SFXTRANS .dsb 04 
ARPINDEX .dsb 04
ARPNUMBO .dsb 04
ARPONOTO .dsb 04
VIBGLBYT .dsb 04
GLDSPEED .dsb 04
GLDDIREC .dsb 04
GLDDELAY .dsb 04
DESTNOTE .dsb 04
VIBDELAY .dsb 04
VIBINDEX .dsb 04
CONTINOS .dsb 04
AMPLITUD .dsb 04
AMPINDEX .dsb 04
FX01 .dsb 04
FX02 .dsb 04	
FX03 .dsb 04	
PULINDEX .dsb 04	
PULSBYT1 .dsb 02

.ende

;----------------------------------------------------------------
; Music Driver Program Start
;----------------------------------------------------------------

        JMP	AUDIOCL
	JMP	AUDIOIN
	JMP	AUDIOPL

AUDIOCL	LDA	#$00
	STA	ENABWORD
	RTS

AUDIOIN	ASL	A
	STA	SEQPOSIT,X	

	LDA	ENABWORD
	ORA	ENABCHAN,X
	STA	ENABWORD
	STA	$4015
	LDA	#$00	 
	STA	SEQINDEX,X
 	STA	SPDINDEX,X
	STA	TRANBYTE,X
	STA	SFXTRANS,X
	STA	STEPNUMB,X
	STA	AMPINDEX,X
	STA	PULINDEX,X
	STA	AMPLITUD,X
	STA	TRANBYTE,X
	STA	CONTINOS,X
     	STA	SPDCOUNT,X
        LDA	#$01
	STA	VOICTEST,X
	STA	LENGCOPY,X
	STA	STPINDEX,X
	RTS

ENABCHAN	DB	$01,$02,$04,$08

AUDIOPL	LDA	VOICTEST,X
	BEQ	AUDIOEX
        LDA	ENABWORD
        STA	$4015
	CPX	#$02
	BCC	VOICE0102
       	BEQ	VOICE03
       	BCS	VOICE04
AUDIOEX	RTS


VOICE04	TXA
	ASL	A
	ASL	A
	TAY
	LDA	#$10		;SETAMPLITUDE             <BIT 04>
	ORA	#$20  		;SETCONTINUES             <BIT 05>
	ORA	AMPLITUD,X	;AMPLITUDE/ENVELOPE-VALUE <BIT 03-00>
	STA	$4000,Y
	LDA	LOFRQWRD,X
	STA	$4002,Y
	LDA	#$F8
	STA	$4003,Y
	JMP	JMPVO04	

VOICE03	TXA
	ASL	A
	ASL	A
	TAY
	LDA	#$80
	JMP	JMPVO03
VOICE0102

SETVOI1	TXA
	ASL	A
	ASL	A
	TAY
	LDA	PULSBYT1,X    	;SETPULSE                 <BIT 07-06>
	ORA	#$10    	;SETAMPLITUDE             <BIT 04>
	ORA	#$20		;SETCONTINUES             <BIT 05>
JMPVO03	ORA	AMPLITUD,X	;AMPLITUDE/ENVELOPE-VALUE <BIT 03-00>
	STA	$4000,Y

	LDA	#$08		;SET-HARDWARE-GLIDE-DOWN		<BIT 03>
	STA	$4001,Y

	LDA	LOFRQWRD,X	;FREQUENCY-SET-ROUTINE
	STA	$4002,Y

	LDA	HIFRQWRD,X
	CMP	CONTINOS,X
	BEQ	NOHINO1
	STA	$4003,Y	
	STA	CONTINOS,X
NOHINO1

JMPVO04

SPDHDL1	LDA	NOTELENG,X	;CUT-OFF-AT-END-ROUTINE
	CMP	#$01
	BEQ	SPEEDROUT
	LDA	LENGCOPY,X
	CMP	#$01
	BNE	SPEEDROUT
	LDA	SPDCOUNT,X
	BNE	SPEEDROUT
	LDA	#$00
	STA	AMPLITUD,X
SPEEDROUT
	
	
	LDA	#$00		;SPEED-ROUTINE
	STA	REALPLAY,X
	DEC	SPDCOUNT,X
	BPL	SPDHDX1

	LDY	SEQPOSIT,X
	LDA	SPDTABEL+$00,Y
	STA	SSSLO
	LDA	SPDTABEL+$01,Y
	STA	SSSHI

	LDY	SPDINDEX,X
	LDA	(SSSLO),Y
	CMP	#$FF
	BNE	SETSPEED
	LDY	#$00
	LDA	(SSSLO),Y
SETSPEED	STA	SPDCOUNT,X
	INY
	TYA
	STA	SPDINDEX,X
	LDA	#$FF
	STA	REALPLAY,X
SPDHDX1	
       	LDA	REALPLAY,X	;CHECK IF NEW LENG SUBTRACTION NECESSARY
	BPL	NOSTPH1	

AUDIPL1	DEC	LENGCOPY,X	;DECREASE SPEED, IF ZERO THEN STEPHANDLE
	BEQ	STPHDL1	

NOSTPH1	LDA	REALNOTE,X	;CHECK REALNOTE ON PAUSE, NO FX
	CMP	#$FF
	BEQ	NOFXPL1
	JSR	PLAYFIX

NOFXPL1	RTS

STPHDL1	LDY	STEPNUMB,X	;WHAT STEP TO TAKE
	LDA	STPTABLO,Y
	STA	SSSLO
	LDA	STPTABHI,Y
	STA	SSSHI

	LDA	#$00		;RESET GLIDE (IF NOT REACHED DEST. NOTE)
	STA	GLDSPEED,X

	LDY	STPINDEX,X	;READ STEP-INDEX
	LDA	(SSSLO),Y
	CMP	#$FF		;STEP CHECK ON END 
	BEQ	SEQHDL1		;YES, GOTO SEQUENCE-HANDLE
	JMP	STPHD12		;NO, GOTO STEPHANDLE 02

SEQHDL1	
	LDY	SEQPOSIT,X	;WHAT SEQUENCE TO TAKE
	LDA	SEQTABEL+$00,Y	;
	STA	SSSLO		;
	LDA	SEQTABEL+$01,Y	;
	STA	SSSHI		;

	LDY	SEQINDEX,X	;READ SEQUENCE-INDEX
	LDA	(SSSLO),Y		;
	CMP	#$FF		;CHECK SEQUENCE ON END-REPEAT
	BNE	SEQHD12		;
	INY			;
	LDA	(SSSLO),Y		;WHERE TO JUMP BACK IN SEQUENCE
	STA	SEQINDEX,X	;
	TAY			;
	LDA	(SSSLO),Y		;
	JMP	SEQHD15		;GOTO NEXT SEQUENCE

SEQHD12	CMP	#$FE		;CHECK SEQUENCE ON END-REAL
	BNE	SEQHD13		;
	LDA	#$00		;YES, DISABLE VOICE
	STA	VOICTEST,X	;
	STA	AMPLITUD,X
	RTS

SEQHD13	
SEQHD15	CMP	#$80		;NOTE TRANSPOSE	CHECK
	BCC	SEQHD16  	      
       	AND	#$7F
NOTRNSI	STA	TRANBYTE,X
	INY
	LDA	(SSSLO),Y
	BMI	NONWSTP

SEQHD16	CMP	#$70
	BCC	SEQHD17
	AND	#$0F
	STA	SFXTRANS,X
	INY
	LDA	(SSSLO),Y

SEQHD17	STA	STEPNUMB,X	;SET STEP & CLEAR STEPINDEX
	INY
NONWSTP	TYA
	STA	SEQINDEX,X
	LDA	#$00
	STA	STPINDEX,X
	JMP	STPHDL1		;BACK TO STEP-HANDLE

STPHD12	CMP	#$FD		;GLIDE CHECK IN STEP
	BNE	STPHD14
	INY
	LDA	(SSSLO),Y
	STA	GLDSPEED,X
	INY
	LDA	(SSSLO),Y
	CLC
	ADC	TRANBYTE,X
	STA	REALNOTE,X
	INY
	LDA	(SSSLO),Y
	CLC
	ADC	TRANBYTE,X
	STA	DESTNOTE,X
	INY
	JMP	NONEWN1

STPHD14	CMP	#$E0		;PAUSE CHECK
	BCC	STPHD15
	AND	#$1F
	STA	NOTELENG,X
	LDA	#$FF
	STA	REALNOTE,X
	LDA	#$00
	STA	AMPLITUD,X
	INY
	TYA
	STA	STPINDEX,X
	JMP	PAUSEX1

STPHD15	CMP	#$C0		;SOUND CHECK
	BCC	STPHD16
	AND	#$1F
	CLC
	ADC	SFXTRANS,X
	ASL	A
	ASL	A
	STA	REALSOUN,X
;	LDA	SEQPOSIT,X
;	CMP	#$30*2
;	BCC	NOEXTRSN
;	LDA	REALSOUN,X
;	CLC
;	ADC	#$80
;	STA	REALSOUN,X

NOEXTRSN	INY
	LDA	(SSSLO),Y
	CMP	#$FD	
	BEQ	STPHD12
	CMP	#$C0
	BCS	NONEWN1
	
STPHD16	CMP	#$80		;LENGTH CHECK
	BCC	STPHD17
	AND	#$7F
	STA	NOTELENG,X
	INY
	LDA	(SSSLO),Y
	CMP	#$FD
	BEQ	STPHD12
	CMP	#$80
	BCS	NONEWN1

STPHD17	CMP	#$60		;ARP CHECK
	BCC	STPHD18
	AND	#$1F	
	STA	ARPNUMBO,X
;	LDA	SEQPOSIT,X
;	CMP	#$30*2
;	BCC	NOEXTARP
;	LDA	ARPNUMBO,X
;	CLC
;	ADC	#$20
;	STA	ARPNUMBO,X
NOEXTARP	INY
	LDA	(SSSLO),Y
	CMP	#$60
	BCS	NONEWN1

STPHD18	CLC			;SET NOTE + NOTE TRANSPOSE
	ADC	TRANBYTE,X	;
	STA	REALNOTE,X	;
	INY			;
NONEWN1	TYA
	STA	STPINDEX,X	;RESTORE STEP-INDEX

	LDY	REALSOUN,X	;
	CPX	#$02		;CHECK SOUND-INIT VOICE 01
	BCS	INITV0304		;

INITV12	LDA	SOUNDFIX+$00,Y	;CHECK IF NEW PULSE TO BE SET
	AND	#$08		;
	BNE	NONEWPL		;
	LDA	SOUNDFIX+$00,Y	;YES, SET NEW PULSE
	AND	#$C0		;
	STA	PULSBYT1,X     	;
	LDA	#$00
	STA	PULINDEX,X
INITV0304

NONEWPL	LDA	SOUNDFIX+$01,Y	;SET VIBRATO-BYTE INTO FX01 & SET EFFECTS (ARP, ETC)
	STA	FX01,X		;
	LDA	SOUNDFIX+$02,Y	;SET VIBDELAY PULTAB-NUMBER INTO FX02
	STA	FX02,X		;
	
NONEWG1	LDA	SOUNDFIX+$03,Y	;SET EFFECT-VALUES INTO FX03	
	STA	FX03,X		;
	CPX	#$03
	BEQ	NFORV04

	LDY	REALNOTE,X	;READ REALNOTE AS INDEX
	LDA	FRQTABLO,Y 	;LOW-FREQUENCY READ <BIT 07-00>
	STA	LOFRQWRD,X	;

	LDA	#$F8		;HARDWARE LENGTH ENDLESS <BIT 07-03>
	ORA	FRQTABHI,Y 	;HI-FREQUENCY READ <BIT 02-00>
	STA	HIFRQWRD,X	;HF SET
	JMP	PAUSEX1

NFORV04	LDA	REALNOTE,X
	STA	LOFRQWRD,X

PAUSEX1	LDA	NOTELENG,X
       	STA	LENGCOPY,X

	LDA	#$00
      	STA	AMPINDEX,X
	STA	VIBINDEX,X
       	STA	ARPINDEX,X
;----------------------------------------------------------------------------
INTPLA1	LDA	GLDSPEED,X
	BEQ	FXPLA12
	TAY	
	LSR	A
	LSR	A
	LSR	A
	LSR	A
	STA	GLDDELAY,X
	TYA
	AND	#$0F
	STA	GLDSPEED,X

	LDA	NOTELENG,X
	SEC
	SBC	GLDDELAY,X
	STA	GLDDELAY,X
	LDA	REALNOTE,X
	SEC
	SBC	DESTNOTE,X
	STA	GLDDIREC,X

FXPLA12	LDA	FX02,X
	LSR	A
	LSR	A
	LSR	A
	LSR	A
	STA	VIBDELAY,X
	LDA	NOTELENG,X
	SEC
	SBC	VIBDELAY,X
	BCS	REFIX01
	LDA	FX01,X
	AND	#$C0
	STA	FX01,X
	JMP	EXITIN1
REFIX01	STA	VIBDELAY,X
EXITIN1      	RTS

PLAYFIX
             ;LDA	LENGCOPY,X	;CHECK IF THE REAL NOTELENGTH IS 1
             ;CMP	#$01
             ;BNE	NOAMPCUT		;IF SO, DO NOT CUT NOTE OFF AT END

             ;LDA	NOTELENG,X
             ;CMP	#01
             ;BNE	NOAMPCUT
             ;LDA	SPDCOUNT,X	;!
             ;CMP	#01		;!
             ;BCS	NOAMPCUT		;!
             ;LDA	#$01
             ;STA	AMPLITUD,X
             ;JMP	NOAMPL1	
NOAMPCUT



	LDA	FX03,X		   ;AMPLITUDE-ROUTINE		
       	AND	#$7F			
       	TAY
       	LDA	AMPTABL,Y
       	STA	SSSLO
       	LDA	AMPTABH,Y
       	STA	SSSHI
       
       	LDY	AMPINDEX,X
       	LDA	(SSSLO),Y
 	CMP	#$FE
       	BEQ	NOAMPL1
       	STA	AMPLITUD,X
       	INC	AMPINDEX,X
NOAMPL1	

GLIDE1	LDY	GLDSPEED,X	  ;PORTAMENTO-ROUTINE
	BEQ	NOGLD12

	LDA	GLDDELAY,X
	CMP	LENGCOPY,X
	BCS	DOPORTA
	JMP	PORTABIZZY
DOPORTA
	LDY	GLDDIREC,X
	BMI	DOWNGL1
	LDA	LOFRQWRD,X
	CLC
	ADC	GLDSPEED,X
	STA	LOFRQWRD,X
	BCC	CHECKV1
       	INC	HIFRQWRD,X

CHECKV1	LDY	DESTNOTE,X
	SEC
	SBC	FRQTABLO,Y
	BCC	NOGLD01
	BCS	FROTER1

DOWNGL1	LDA	LOFRQWRD,X
	SEC
	SBC	GLDSPEED,X
	STA	LOFRQWRD,X
	BCS	CHECKV2
	DEC	HIFRQWRD,X
	
CHECKV2	LDY	DESTNOTE,X
	SEC
	SBC	FRQTABLO,Y
	BCS	NOGLD01
FROTER1	TYA
	STA	REALNOTE,X
       	LDA	FRQTABLO,Y
       	STA	LOFRQWRD,X
       	LDA	FRQTABHI,Y
       	STA	HIFRQWRD,X
	
	LDA	#$00
	STA	GLDSPEED,X
NOGLD01	JMP	NOVIB01
NOGLD12

	LDA	GLDSPEED,X
	BNE	PORTABIZZY

VIBRA01	LDA	FX01,X	 	;VIBRATO-ROUTINE
        AND	#$0F
        BEQ	NOVIB01
        LDA	VIBDELAY,X
        CMP	LENGCOPY,X
        BCC	NOVIB01

        LDA	FX01,X
        AND	#$0F
        TAY
        LDA	VIBTABL-1,Y
        STA	SSSLO
        LDA	VIBTABH-1,Y
        STA	SSSHI

        LDY	VIBINDEX,X
        LDA	(SSSLO),Y
        CMP	#$80
	BNE	VIB01
	LDY	#$00
VIB01	LDA	(SSSLO),Y
	BPL	UPVIBOS
	EOR	#$FF
	CLC
	ADC	#$01
	STA	SSSLO
	LDA	LOFRQWRD,X
	SEC
	SBC	SSSLO
	STA	LOFRQWRD,X
	BCS	NOHIGH1
	DEC	HIFRQWRD,X
NOHIGH1	JMP	VIBNO01
       
UPVIBOS	LDA	LOFRQWRD,X
	CLC
	ADC	(SSSLO),Y
	STA	LOFRQWRD,X
	BCC	NOHIGH2
       	INC	HIFRQWRD,X
NOHIGH2		
VIBNO01	INY
	TYA
	STA	VIBINDEX,X
NOVIB01

PORTABIZZY

PULSE1 	CPX	#$02
       	BCS	NOPULS1
       	LDA	FX02,X	 	;PULSE ROUTINE
       	AND	#$0F
       	BEQ	NOPULS1
       	TAY	      
       	LDA	PULTABL-1,Y
       	STA	SSSLO
       	LDA	PULTABH-1,Y
       	STA	SSSHI

       	LDY	PULINDEX,X
       	LDA	(SSSLO),Y
	CMP	#$FE
	BEQ	NOPULS1
       	CMP	#$FF
       	BNE	PULS01
       	INY
       	LDA	(SSSLO),Y
	TAY
       	LDA	(SSSLO),Y

PULS01 	STA	PULSBYT1,X
       	INY
       	TYA
	STA	PULINDEX,X	
NOPULS1	

ARPEG01	LDA	FX01,X		;ARP ROUTINE
	AND	#$40		
	BEQ	NOARP01
	LDY	ARPNUMBO,X
	LDA	FX01,X
	BPL	NOARPADD
	TYA
	CLC
	ADC	#$20
	TAY
NOARPADD	LDA	ARPTABLO,Y
	STA	SSSLO
	LDA	ARPTABHI,Y
	STA	SSSHI
	LDY	ARPINDEX,X
     	LDA	(SSSLO),Y
	CMP	#$FE
	BEQ	NOARP01
	CMP	#$FF
	BNE	ARP03
	INY
	LDA	(SSSLO),Y
	TAY
	LDA	(SSSLO),Y
ARP03	BMI	NORMA01
	CLC
	ADC	REALNOTE,X
NORMA01	AND	#$7F
	STA	ARPONOTO,X
	INY
	TYA
	STA	ARPINDEX,X
ARPNO01	LDA	ARPONOTO,X
	CPX	#$03
	BNE	SETAN01
	STA	LOFRQWRD,X
	JMP	NOARP01
SETAN01
	TAY
	LDA	FRQTABLO,Y
	STA	LOFRQWRD,X
	LDA	FRQTABHI,Y
	STA	HIFRQWRD,X
NOARP01	RTS

;----------------------------------------------------------------
; Data
;----------------------------------------------------------------

FRQTABLO	DB $AD,$4A,$EF,$9B,$4B,$FE,$B5,$73,$30,$F5,$BD,$87 ;1
        	DB $56,$25,$F8,$CD,$A5,$7F,$5B,$3A,$19,$FB,$DE,$C3 ;2
        	DB $AA,$92,$7B,$66,$52,$3F,$2D,$1C,$0C,$FD,$EF,$E1 ;3
        	DB $D4,$C9,$BD,$B3,$A9,$9F,$96,$8E,$86,$7E,$77,$70 ;4
        	DB $6A,$64,$5E,$59,$54,$4F,$4A,$47,$42,$3E,$3B,$38 ;5
        	DB $35,$31,$2E,$2C,$29,$27,$25,$23,$21,$1F,$1D,$1B ;6
        	DB $1A,$19,$18,$16,$15,$14,$13,$12,$11,$10,$0F,$0E ;7
        	DB $07	  	

FRQTABHI	DB $06,$06,$05,$05,$05,$04,$04,$04,$04,$03,$03,$03 ;1
        	DB $03,$03,$02,$02,$02,$02,$02,$02,$02,$01,$01,$01 ;2
        	DB $01,$01,$01,$01,$01,$01,$01,$01,$01,$00,$00,$00 ;3
        	DB $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 ;4
        	DB $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 ;5
        	DB $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 ;6
        	DB $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00 ;7
        	DB $00
;-----------------------------------------------------------------------------------------------



STPTABLO	DB <S00,<S01,<S02,<S03,<S04,<S05,<S06,<S07,<S08,<S09,<S0A,<S0B,<S0C,<S0D,<S0E,<S0F
        	DB <S10,<S11,<S12,<S13,<S14,<S15,<S16,<S17,<S18,<S19,<S1A,<S1B,<S1C,<S1D,<S1E,<S1F
        	DB <S20,<S21,<S22,<S23,<S24,<S25,<S26,<S27,<S28,<S29,<S2A,<S2B,<S2C,<S2D,<S2E,<S2F
        	DB <S30,<S31,<S32,<S33,<S34,<S35,<S36,<S37,<S38,<S39,<S3A,<S3B,<S3C,<S3D,<S3E,<S3F
        	DB <S40,<S41,<S42,<S43,<S44,<S45,<S46,<S47,<S48,<S49,<S4A,<S4B,<S4C,<S4D,<S4E,<S4F
        	DB <S50,<S51,<S52,<S53,<S54,<S55,<S56,<S57,<S58,<S59,<S5A,<S5B,<S5C,<S5D,<S5E,<S5F
        	DB <S60,<S61,<S62,<S63,<S64,<S65,<S66,<S67,<S68,<S69,<S6A,<S6B,<S6C,<S6D,<S6E,<S6F
        	DB <S70,<S71,<S72,<S73,<S74,<S75,<S76,<S77,<S78,<S79,<S7A,<S7B,<S7C,<S7D,<S7E,<S7F
	
STPTABHI	DB >S00,>S01,>S02,>S03,>S04,>S05,>S06,>S07,>S08,>S09,>S0A,>S0B,>S0C,>S0D,>S0E,>S0F
        	DB >S10,>S11,>S12,>S13,>S14,>S15,>S16,>S17,>S18,>S19,>S1A,>S1B,>S1C,>S1D,>S1E,>S1F
        	DB >S20,>S21,>S22,>S23,>S24,>S25,>S26,>S27,>S28,>S29,>S2A,>S2B,>S2C,>S2D,>S2E,>S2F
        	DB >S30,>S31,>S32,>S33,>S34,>S35,>S36,>S37,>S38,>S39,>S3A,>S3B,>S3C,>S3D,>S3E,>S3F
        	DB >S40,>S41,>S42,>S43,>S44,>S45,>S46,>S47,>S48,>S49,>S4A,>S4B,>S4C,>S4D,>S4E,>S4F
        	DB >S50,>S51,>S52,>S53,>S54,>S55,>S56,>S57,>S58,>S59,>S5A,>S5B,>S5C,>S5D,>S5E,>S5F
        	DB >S60,>S61,>S62,>S63,>S64,>S65,>S66,>S67,>S68,>S69,>S6A,>S6B,>S6C,>S6D,>S6E,>S6F
        	DB >S70,>S71,>S72,>S73,>S74,>S75,>S76,>S77,>S78,>S79,>S7A,>S7B,>S7C,>S7D,>S7E,>S7F

AMPTABL 	DB	<AM00,<AM01,<AM02,<AM03,<AM04,<AM05,<AM06,<AM07,<AM08,<AM09,<AM0A,<AM0B,<AM0C,<AM0D,<AM0E,<AM0F
        	DB <AM10,<AM11,<AM12,<AM13,<AM14,<AM15,<AM16,<AM17,<AM18
AMPTABH 	DB	>AM00,>AM01,>AM02,>AM03,>AM04,>AM05,>AM06,>AM07,>AM08,>AM09,>AM0A,>AM0B,>AM0C,>AM0D,>AM0E,>AM0F
        	DB >AM10,>AM11,>AM12,>AM13,>AM14,>AM15,>AM16,>AM17,>AM18

VIBTABL 	DB <V01,<V02,<V03,<V04,<V05,<V06,<V07,<V08
VIBTABH 	DB >V01,>V02,>V03,>V04,>V05,>V06,>V07,>V08

PULTABL 	DB <P01,<P02,<P03,<P04,<P05,<P06,<P07,<P08
PULTABH 	DB >P01,>P02,>P03,>P04,>P05,>P06,>P07,>P08

ARPTABLO	DB <A00,<A01,<A02,<A03,<A04,<A05,<A06,<A07,<A08,<A09,<A0A,<A0B,<A0C,<A0D,<A0E,<A0F
        	DB <A10,<A11,<A12,<A13,<A14,<A15,<A16,<A17,<A18,<A19,<A1A,<A1B,<A1C,<A1D,<A1E,<A1F
        	DB <A20,<A21,<A22,<A23,<A24,<A25,<A26,<A27,<A28,<A29,<A2A,<A2B,<A2C,<A2D,<A2E,<A2F
	        DB <A30,<A31,<A32,<A33
ARPTABHI DB >A00,>A01,>A02,>A03,>A04,>A05,>A06,>A07,>A08,>A09,>A0A,>A0B,>A0C,>A0D,>A0E,>A0F
         DB >A10,>A11,>A12,>A13,>A14,>A15,>A16,>A17,>A18,>A19,>A1A,>A1B,>A1C,>A1D,>A1E,>A1F
         DB >A20,>A21,>A22,>A23,>A24,>A25,>A26,>A27,>A28,>A29,>A2A,>A2B,>A2C,>A2D,>A2E,>A2F,>A30,>A31,>A32,>A33

;----------------------------------------------------------------------------------------------------------------

INITVAL0	=	$01
INITVAL1	=	$02
INITVAL2	=	$03
INITVAL3	=	$04
					   

SFXTAB0	DB $01,$05,$09,$0C,$0E,$10,$12,$14 ;TABLE REMOVABLE!
	DB $16,$18,$1A,$1E,$22,$00,$00,$28
	DB $00,$00,$00,$00,$00,$00,$00,$00
	DB $00,$00,$00,$00,$00,$00,$00,$00
	DB $00,$00,$00,$00,$00,$00,$00,$00
	DB $00,$00,$00,$00,$00,$00,$00,$00
	DB $00,$00,$00,$00,$00,$00,$00,$00
	DB $00,$00,$00,$00,$00,$00,$00,$00

SFXTAB1	DB $02,$06,$0A,$0D,$0F,$11,$13,$15
	DB $17,$19,$1B,$1F,$23,$00,$00,$29
	DB $00,$00,$00,$00,$00,$00,$00,$00
	DB $00,$00,$00,$00,$00,$00,$00,$00
	DB $00,$00,$00,$00,$00,$00,$00,$00
	DB $00,$00,$00,$00,$00,$00,$00,$00
	DB $00,$00,$00,$00,$00,$00,$00,$00
	DB $00,$00,$00,$00,$00,$00,$00,$00

SFXTAB2	DB $03,$07,$00,$00,$00,$00,$00,$00
	DB $00,$00,$1C,$20,$24,$26,$27,$00
	DB $00,$00,$00,$00,$2E,$00,$31,$32
	DB $33,$35,$36,$37,$38,$39,$3A,$00
	DB $3C,$3E,$40,$42,$43,$45,$46,$47
	DB $48,$49,$4A,$4B,$4C,$4D,$4E,$50
	DB $51,$52,$53,$00,$00,$00,$00,$00
	DB $00,$00,$00,$00,$00,$00,$00,$00

SFXTAB3	DB $04,$08,$0B,$00,$00,$00,$00,$00
	DB $00,$00,$1D,$21,$25,$00,$00,$00
	DB $2A,$2B,$2C,$2D,$2F,$30,$00,$00
	DB $34,$00,$00,$00,$00,$00,$00,$3B
	DB $3D,$3F,$41,$00,$44,$00,$00,$00
	DB $00,$00,$00,$00,$00,$00,$4F,$00
	DB $00,$00,$00,$00,$00,$00,$00,$00
	DB $00,$00,$00,$00,$00,$00,$00,$00 ;TILL HERE!

				; LDA LDX
SEQTABEL	
        DW	CLEARAUD	; $00 $XX
	DW	DR_TTLSFT0	; $01 $00
	DW	DR_TTLSFT1	; $02 $01
	DW	DR_TTLSFT2	; $03 $02
	DW	DR_TTLSFT3	; $04 $03
	DW	DR_TTLORC0	; $05 $00
	DW	DR_TTLORC1	; $06 $01
	DW	DR_TTLORC2	; $07 $02
	DW	DR_TTLORC3	; $08 $03
	DW	ENTPASSJ0	; $09 $00
	DW	ENTPASSJ1	; $0A $01
	DW	ENTPASSJ3	; $0B $03
	DW	HORRORD0	; $0C $00
	DW	HORRORD1	; $0D $01
	DW	HORRORN0	; $0E $00
	DW	HORRORN1	; $0F $01
	DW	LEVEL10		; $10 $00
	DW	LEVEL11		; $11 $01
	DW	LEVEL20		; $12 $00
	DW	LEVEL21		; $13 $01
	DW	LEVEL30		; $14 $00
	DW	LEVEL31		; $15 $01
	DW	GUARD10		; $16 $00
	DW	GUARD11		; $17 $01
	DW	DRACULA0	; $18 $00
	DW	DRACULA1	; $19 $01
	DW	GAMEOVER0	; $1A $00
	DW	GAMEOVER1	; $1B $01
	DW	GAMEOVER2	; $1C $02
	DW	GAMEOVER3	; $1D $03
	DW	GAMECOMPL0	; $1E $00
	DW	GAMECOMPL1	; $1F $01
	DW	GAMECOMPL2	; $20 $02
	DW	GAMECOMPL3	; $21 $03
	DW	LVLCOMPL0	; $22 $00
	DW	LVLCOMPL1	; $23 $01
	DW	LVLCOMPL2	; $24 $02
	DW	LVLCOMPL3	; $25 $03
	DW	INVINCIB2	; $26 $02
	DW	LOOSELIF2	; $27 $03
	DW	VANHELS0	; $28 $00
	DW	VANHELS1	; $29 $01
	DW	SWRDSWISH3	; $2A $03
	DW	THROWROCK3	; $2B $03
	DW	LOBAXE3		; $2C $03
	DW	LOBTORCH3	; $2D $03
	DW	TORCHSPL2	; $2E $02
	DW	TORCHSPL3	; $2F $03
	DW	TRPLROCK3	; $30 $03
	DW	JUMPER12	; $31 $02
	DW	LANDER12	; $32 $02
	DW	HARDLAND2	; $33 $02
	DW	HARDLAND3	; $34 $03
	DW	AAARGH2		; $35 $02
	DW	SWITCHON2	; $36 $02
	DW	SWITCHOF2	; $37 $02
	DW	MECHWHIR2	; $38 $02
	DW	NMIKILLED2	; $39 $02
	DW	PINGPICK2	; $3A $02
	DW	BLOCKCRMB3	; $3B $03
	DW	SCCCTING2	; $3C $02
	DW	SCCCTING3	; $3D $03
	DW	SCCCTUNG2	; $3E $02
	DW	SCCCTUNG3	; $3F $03
	DW	PHUTROCK2	; $40 $02
	DW	PHUTROCK3	; $41 $03
	DW	RESTPOIN2	; $42 $02
	DW	WOBBWOBB2	; $43 $02
	DW	WOBBWOBB3	; $44 $02
	DW	SUPRPING2	; $45 $02
	DW	MEGAPING2	; $46 $02
	DW	EXTRALIF2	; $47 $02
	DW	CONTCRDT2	; $48 $02
	DW	WARN20SC2	; $49 $02
	DW	COUNTDWN2	; $4A $02
	DW	TIMEOUT2	; $4B $02
	DW	BONUSCNT2	; $4C $02
	DW	BONUSPNG2	; $4D $02
	DW	EXPLOSIO2	; $4E $02
	DW	EXPLOSIO3	; $4F $03
	DW	MISCELLA2	; $50 $02
	DW	MISCELLB2	; $51 $02
	DW	MISCELLC2	; $52 $02
	DW	WARN10SC2	; $53 $02


SPDTABEL
        DW	SP00	        ; $00 $XX
	DW	SP04 		; $01 $00
	DW	SP04		; $02 $01
	DW	SP04		; $03 $02
	DW	SP04		; $04 $03
	DW	SP04		; $05 $00
	DW	SP04		; $06 $01
	DW	SP04		; $07 $02
	DW	SP04		; $08 $03
	DW	SP02		; $09 $00
	DW	SP02		; $0A $01
	DW	SP02		; $0B $03
	DW	SP06		; $0C $00
	DW	SP06		; $0D $01
	DW	SP02		; $0E $00
	DW	SP02		; $0F $01
	DW	SP03		; $10 $00
	DW	SP03		; $11 $01
	DW	SP02		; $12 $00
	DW	SP02		; $13 $01
	DW	SP06		; $14 $00
	DW	SP06		; $15 $01
	DW	SP02		; $16 $00
	DW	SP02		; $17 $01
	DW	SP02		; $18 $00
	DW	SP02		; $19 $01
	DW	SP02		; $1A $00
	DW	SP02		; $1B $01
	DW	SP02		; $1C $02
	DW	SP02		; $1D $03
	DW	SP02		; $1E $00
	DW	SP02		; $1F $01
	DW	SP02		; $20 $02
	DW	SP02		; $21 $03
	DW	SP02		; $22 $00
	DW	SP02		; $23 $01
	DW	SP02		; $24 $02
	DW	SP02		; $25 $03
	DW	SP07		; $26,$02
	DW	SP08		; $27,$02
	DW	SP02		; $28,$00
	DW	SP02		; $29,$01
	DW	SP02		; $2A,$03
	DW	SP02		; $2B,$03
	DW	SP09		; $2C,$03
	DW	SP0A		; $2D,$03
	DW	SP02		; $2E,$02
	DW	SP02		; $2F,$03
	DW	SP0A		; $30,$03
	DW	SP02		; $31,$02
	DW	SP02		; $32,$02
	DW	SP02		; $33,$02
	DW	SP02		; $34,$03
	DW	SP09		; $35,$02
	DW	SP09		; $36,$02
	DW	SP09		; $37,$02
	DW	SP09		; $38,$02
	DW	SP02		; $39,$02
	DW	SP02		; $3A,$02
	DW	SP02		; $3B,$03
	DW	SP02		; $3C,$02
	DW	SP02		; $3D,$03
	DW	SP02		; $3E,$02
	DW	SP02		; $3F,$03
	DW	SP09		; $40,$02
	DW	SP09		; $41,$03
	DW	SP02		; $42,$02
	DW	SP09		; $43,$02
	DW	SP09		; $44,$03
	DW	SP02		; $45,$02
	DW	SP02		; $46,$02
	DW	SP02		; $47,$02
	DW	SP02		; $48,$02
	DW	SP05		; $49,$02	
	DW	SP02		; $4A,$02	
	DW	SP02		; $4B,$02	
	DW	SP02		; $4C,$02
	DW	SP02		; $4D,$02
	DW	SP02		; $4E,$02
	DW	SP02		; $4F,$03
	DW	SP02		; $50,$02
	DW	SP02		; $51,$02
	DW	SP02		; $52,$02
	DW	SP03		; $53,$02


;SP00	DB $00,$FF
;SP02	DB $02,$FF
;SP03	DB $03,$FF
;SP04	DB $04,$03,$FF
;SP05	DB $05,$FF
;SP06	DB $02,$03,$FF
;SP07	DB $07,$FF
;SP08	DB $04,$FF
;SP09	DB $02,$01,$FF

SP00	DB $00,$FF
SP02	DB $02,$FF
SP03	DB $03,$FF
SP04	DB $04,$03,$FF
SP05	DB $05,$FF
SP06	DB $03,$FF
SP07	DB $06,$FF
SP08	DB $04,$FF
SP09	DB $01,$02,$FF
SP0A	DB $01,$FF
;---------------------------------------------------------------------------
AM00	       	
	DB 15,11,10,$FE
AM01
	DB 9,6,5,$FE
AM02
	DB 11,7,6,$FE
AM03
	DB 15,14,13,12,$FE
AM04
	DB 15,14,13,13,12,12,11,11,10,10,9,9,8,8,7,7,6,6,5,5,4,4,3,3,3,2,2,2,1,2,1,1,1,0,1,0,$FE
AM05
	DB 7,4,3,$FE
AM06
	DB 13,11,9,8,7,$FE
AM07
	DB 6,5,4,$FE
AM08
	DB 15,12,8,7,6,5,4,3,2,1,0,$FE
AM09
	DB 1,4,8,12,13,14,15,15,15,15,15,15,15,14,13,13,12,12,11,11,10,10,9,9,8,8,7,7,6,6,5,5,4,4,3,3,3,2,2,1,1,0,$FE
AM0A
	DB 1,3,6,9,12,12,11,10,9,8,7,6,5,4,3,2,1,0,$FE
AM0B
	DB 10,10,9,9,8,8,7,7,6,6,6,5,5,5,4,4,4,3,4,3,3,3,2,3,2,2,2,1,2,1,1,1,0,1,0,$FE
AM0C
	DB 8,8,7,7,6,6,5,5,4,4,3,3,2,2,1,1,0,$FE	
AM0D
	DB 5,5,4,5,4,4,3,4,3,3,2,3,2,2,1,2,1,1,0,1,0,$FE
AM0E
	DB 2,2,1,2,1,1,0,1,0,$FE
AM0F
	DB	15,2,9,4,13,6,11,12,8,4,12,15,10,4,8,15,6,1,14,13,5,14,8,2,10,13,4,15,9,4,14,7,11,4,12,8,4,12,15,10,4,8,14,3,9
	DB 12,9,4,14,7,11,4,13
	DB	13,6,11,12,8,4,12,15,10,4,8,15,6,1,14,13,5,14,8,2,10,13,4,15,9,4,14,7,11,4,12,8,4,12,15,10,4,8,14,3,9
	DB 12,9,4,14,7,11,4
	DB 15,7,5,3,2,1,0,$FE
AM10
	DB 2,4,6,8,10,12,14,15,12,8,4,1,0
	DB $FE
AM11
	DB 10,10,9,10,9,9,8,9,8,8,7,8,7,7,6,7,6,6,5,6,5,5,5
	DB 4,5,4,5,4,4,4,4,3,4,3,4,3,3,3,3,2,3,2,3,2,2,2,2,1,2,1,2,1,1,1,1,0,1,0,1,0
	DB $FE
AM12
	DB	15,15,15,15,14,15,14,15,14,14,14,14,13,14,13,14,13,13,13,13,12,13,12,13,12,12,12,12,11,12,11,12,11,11,11,11
	DB	10,11,10,11,10,10,10,10,9,10,9,10,9,9,9,9,8,9,8,9,8,8,8,8,7,8,7,8,7,7,7,7,6,7,6,7,6,6,6,6,5,6,5,6,5,5,5,5
	DB 4,5,4,5,4,4,4,4,3,4,3,4,3,3,3,3,2,3,2,3,2,2,2,2,1,2,1,2,1,1,1,1,0,1,0,1,0,$FE
AM13
	DB 15,14,13,12,11,10,9,8,8,7,7,6,6,5,5,4,4,3,3,2,2,1,$FE
AM14	
AM15	
AM16
AM17
AM18	
;-----------------------------------------------------------------------------
V01		
	DB $03,$02,$02,$02,$FD,$FD,$FD
	DB $FD,$FE,$FE,$FE,$03,$03,$03
	DB $80
V02
	DB $01,$FF
	DB $80	
V03	     
	DB $01,$01,$01,$00,$FF,$FF,$FF
	DB $FF,$FF,$FF,$00,$01,$01,$01
	DB $80
V04	     
	DB $01,$01,$01,$01,$FE,$FF,$FF
	DB $FF,$FF,$FF,$FF,$02,$01,$01
	DB $80
V05	     
V06	     
V07	     
V08	     
;-----------------------------------------------------------------------------
P01	DB $40,$40,$40,$40,$40,$40,$40,$40
	DB $00,$00,$00,$00,$00,$00,$00,$00
	DB $40,$40,$40,$40,$40,$40,$40,$40
	DB $40,$40,$40,$40,$40,$40,$40,$40
	DB $80,$80,$80,$80,$80,$80,$80,$80
	DB $80,$80,$80,$80,$80,$80,$80,$80
	DB $C0,$C0,$C0,$C0,$C0,$C0,$C0,$C0
	DB $C0,$C0,$C0,$C0,$C0,$C0,$C0,$C0
	DB $80,$80,$80,$80,$80,$80,$80,$80
	DB $80,$80,$80,$80,$80,$80,$80,$80
	DB $FF,$12
P02
	DB $80,$80,$80,$80,$80,$80,$80,$80,$80,$80,$80,$80
	DB $40,$40,$40,$40,$40,$40,$40,$40,$40,$40,$40,$40
	DB $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
	DB $40,$40,$40,$40,$40,$40,$40,$40,$40,$40,$40,$40
	DB $FF,$00
P03
	DB $40,$40,$40,$40,$40,$40,$40,$40,$40,$40,$40,$40
	DB $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
	DB $40,$40,$40,$40,$40,$40,$40,$40,$40,$40,$40,$40
	DB $80,$80,$80,$80,$80,$80,$80,$80,$80,$80,$80,$80
	DB $FF,$00
P04
P05
P06
P07
P08
;-----------------------------------------------------------------------------
A00	DB 7,3,0,7,7,3,3,0,0,7,7,7,3,3,3,0,0,0,7,7,7,7,3,3,3,3,0,$FF,$0F
A01	DB 7,4,0,7,7,4,4,0,0,7,7,7,4,4,4,0,0,0,7,7,7,7,4,4,4,4,0,$FF,$0F
A02	DB 8,5,0,8,8,5,5,0,0,8,8,8,5,5,5,0,0,0,8,8,8,8,5,5,5,5,0,$FF,$0F
A03	DB 9,5,0,9,9,5,5,0,0,9,9,9,5,5,5,0,0,0,9,9,9,9,5,5,5,5,0,$FF,$0F
A04	DB 8,3,0,8,8,3,3,0,0,8,8,8,3,3,3,0,0,0,8,8,8,8,3,3,3,3,0,$FF,$0F
A05	DB 9,4,0,9,9,4,4,0,0,9,9,9,4,4,4,0,0,0,9,9,9,9,4,4,4,4,0,$FF,$0F
A06	DB 12,12,12,7,7,7,0,0,0,$FF,$00
A07	DB 12,12,12,6,6,6,0,0,0,$FF,$00
A08	DB 12,12,12,5,5,5,0,0,0,$FF,$00
A09	DB 12,12,12,3,3,3,0,0,0,$FF,$00
A0A	DB 7,7,5,5,0,0,$FF,$00
A0B	DB 13,8,1,12,7,0,$FF,$00
A0C	DB 6,3,0,6,6,3,3,0,0,6,6,6,3,3,3,0,0,0,6,6,6,6,3,3,3,3,0,$FF,$0F
A0D	DB 6,4,0,6,6,4,4,0,0,6,6,6,4,4,4,0,0,0,6,6,6,6,4,4,4,4,0,$FF,$0F
A0E	DB 7,5,0,7,7,5,5,0,0,7,7,7,5,5,5,0,0,0,7,7,7,7,5,5,5,5,0,$FF,$0F
A0F	DB 0,4,8,12,13,13,13,12,13,12,12,8,12,8,8,7,8,7,7,1,7,7,1,1,0,1,0,0,8,8,0,8,8,7,8,8,7,7,13,7,$FF,$04
A10	DB 1,0,$FF,$00
A11	DB 5,5,0,0,5,5,5,0,$FF,$02
A12	DB 6,6,0,0,6,6,6,0,$FF,$02
A13	DB 7,7,0,0,7,7,7,0,$FF,$02
A14	DB 3,3,0,0,3,3,3,0,$FF,$02
A15	DB 2,2,0,0,2,2,2,0,$FF,$02
A16	DB 10,10,0,10,10,10,0,$FF,$02
A17	DB 9,9,0,0,9,9,9,0,$FF,$02
A18	DB 8,8,0,0,8,8,8,0,$FF,$02
A19	DB 7,1,0,7,7,1,1,0,$FF,$02
A1A	DB $00,$02,$04,$06,$FE
A1B	DB 10,10,5,5,0,0,$FF,$00
A1C	DB 0,$FE
A1D	DB 4,14,25,9,11,34,6,18,29,7,31,12,5,8,16,7,34,5,8,$FF,$00
A1E	DB 2,0,3,1,4,2,6,4,8,6,11,9,14,12,17,15,19,17,20,18,21,19,22,20,23,21,24,22,$FF,$00
A1F	DB 20,18,22,20,24,20,21,17,18,14,15,11,12,8,9,6,8,5,7,4,6,3,5,2,4,1,3,0,2,0,1,0,$FF,$00	

A20	DB 0,0,0,5,0,5,5,5,7,5,7,7,7,10,7,10,10,10,0,10,$FF,$00
A21	DB 0,0,0,6,0,6,6,6,12,6,12,12,12,18,12,18,18,18,0,18,$FF,$00
A22	DB 0,1,2,4,7,10,15,19,21,23,24,24,28,24,28,28,31,28,31,31,24,31,$FF,$0A
A23	DB 12,12,12,0,0,12,12,0,0,0,$FF,$00
A24	DB 0,1,2,3,4,2,3,1,2,0,$FF,$04
A25	DB 6,6,6,0,6,0,0,0,6,0,$FF,$00
A26	DB 24,24,18,24,18,18,12,18,12,12,6,12,6,6,0,6,0,0,24,0,$FF,$00
A27	DB 0,3,6,12,15,18,12,0,0,3,3,6,6,12,12,15,15,18,18,$FF,$07
A28	DB 0,1,0,1,0,1,0,1,8,9,8,9,8,9,8,9,$FF,$00
A29	DB 9,7,11,9,13,11,15,13,11,9,10,8,9,7,8,6,8,6,7,5,7,5,6,4,6,4,5,3,5,3,4,2,4,2,3,1,3,1,2,0,2,0
	DB $FF,$0E
A2A	DB 12,8,10,6,8,4,6,2,4,0,$FF,$00
A2B	DB 0,12,1,11,2,10,3,9,4,8,5,7,6,6,7,5,8,4,9,3,10,2,11,1,12,0,$FF,$00
A2C	DB 0,0,0,5,0,5,5,5,10,0,10,10,10,3,10,3,3,3,8,3,8,8,8,13,8,13,13,13,0,13,$FF,$00
A2D	DB 0,$FE
A2E	DB $A4,$A1,$9F,$9E,$9D,$9C,$9B,$9A,$99,$98,$97,$96,$95
	DB $94,$93,$92,$91,$90,$8F,$8E,$8D,$8C,$8B,$8A,$89,$88
	DB $87,$86,$85,$84,$83,$82,$81,$80,$00,$FE
A2F	DB 1,0,$FE
A30	DB $AA,$A8,$A6,$A4,$A3,$A2,$00,$FE
A31	DB $86,0,$FE
A32	DB $9C,$99,$97,$96,$00,$FE
A33	DB $A3,$A2,$A1,$A0,$00,$FE
;-----------------------------------------------------------------------------
SOUNDFIX


;NES                              PUL,ARP/VIBTAB,VIBDEL/PULTAB,AMPTAB


;SOFTLEAD
		DB	$48,$03,$41,$00	;C0   
;SOFTLEAD-1
		DB	$48,$03,$41,$01	;C1   
;ARPEGSFT
		DB	$48,$40,$01,$02	;C2   
;HARDLEAD
		DB	$88,$03,$42,$03	;C3   
;ARPEGSFT
		DB	$48,$40,$01,$03	;C4   
;SISSERSHARD
		DB	$00,$00,$00,$04	;C5   
;SOFTLEAD-2
		DB	$48,$03,$41,$05	;C6   
;MIDLEAD
		DB	$88,$03,$42,$06	;C7   
;MIDLEAD-1
		DB	$88,$03,$42,$07	;C8   
;MIDARPLEAD
		DB	$88,$40,$02,$06	;C9   
;MIDARPLEAD-1
		DB	$88,$40,$02,$07	;CA   
;BASSVIBWIDE
		DB	$48,$01,$41,$03	;CB   
;HARDARP
		DB	$48,$40,$01,$03	;CC   
;SISSERSSOFTARP
		DB	$00,$40,$00,$08	;CD   
;SISSERSSOFT
		DB	$00,$00,$00,$08	;CE   
;LONGFADEU&D	
		DB	$00,$40,$00,$09	;CF
;LONGFADEU&D+V	
		DB	$00,$43,$40,$09	;D0
;SHORTFADEU&D	
		DB	$00,$40,$00,$0A	;D1
;SISSERSARP
		DB	$00,$40,$00,$04	;D2   
;MIDSOUNDFADE
		DB	$00,$40,$00,$0B	;D3   
;SHORTFADEMID
		DB	$00,$40,$00,$0C	;D4   
;SHORTFADEMI-1		
		DB	$00,$40,$00,$0D	;D5   
;SHORTFADEMI-2
		DB	$00,$40,$00,$0E	;D6   
;PING!
		DB	$40,$01,$10,$0B	;D7   
;RANDOM
		DB	$00,$00,$00,$0F	;D8   
;CHCHFADEUP
		DB	$00,$00,$00,$10	;D9   
;METALPINGFADE		  
		DB	$00,$02,$10,$0B	;DA   
;PING-EXCELLENT
		DB	$00,$C0,$00,$11	;DB   
;EXPLOSION
		DB	$00,$C0,$00,$12	;DC   
;SOFTADDARPLEAD
		DB	$08,$C3,$41,$00	;DD   
;MIDLEAD
		DB	$48,$C3,$43,$06	;DE   
;SISFADEMIDQUIK
		DB	$00,$C0,$00,$13	;DF   


DR_TTLSFT0
	DB	$80,$01
	DB	$FF,$00
DR_TTLSFT1
	DB	$80,$03,$03
	DB	$FF,$00
DR_TTLSFT2
	DB	$80,$02
	DB	$FF,$00
DR_TTLSFT3
	DB	$80,$04
	DB	$FF,$00

S01
	DB	$C0,$88,$18
	DB	$C0,$88,$24
	DB	$C0,$86,$20,$81,$22,$20
	DB	$C0,$88,$1F
	DB	$C0,$88,$18
	DB	$C0,$88,$24
	DB	$C0,$86,$1F,$81,$20,$1F
	DB	$C0,$88,$1E
	DB	$C0,$88,$1D
	DB	$C0,$88,$19
	DB	$C0,$88,$16
	DB	$C0,$86,$14,$81,$16,$14
	DB	$C0,$84,$13,$14
	DB	$C0,$84,$1F,$20
	DB	$C0,$82,$2B,$2C,$2B,$2C
	DB	$C0,$81,$37,$38,$37,$38,$37,$38,$37,$38
	
	DB	$C0,$86,$18,$81,$19,$1F
	DB	$C0,$86,$24,$81,$25,$24
	DB	$C0,$86,$20,$81,$22,$24
	DB	$C0,$86,$1F,$81,$20,$1F
	DB	$C0,$86,$18,$81,$19,$1F
	DB	$C0,$86,$24,$81,$25,$24
	DB	$C0,$86,$1F,$81,$20,$1F
	DB	$C0,$86,$1E,$81,$2A,$36
	DB	$C0,$84,$1D,$81,$1E,$1D,$1E,$1D
	DB	$C0,$84,$19,$81,$1B,$19,$1B,$19
	DB	$C0,$84,$16,$81,$17,$16,$17,$16
	DB	$C0,$84,$14,$81,$16,$14,$16,$14
	DB	$C0,$84,$13
	DB	$C0,$84,$14
	DB	$C0,$82,$1F,$20,$1F,$20
	DB	$C0,$81,$2B,$2C,$2B,$2C,$2B,$2C,$2B,$2C
	DB	$C0,$81,$2B,$2A,$27,$26,$1F,$1E,$1B,$1A
	DB	$C0,$98,$18,$81,$19,$18,$14,$18,$14,$13,$0D,$13
	DB	$C0,$98,$0C,$81,$0D,$0C,$08,$0C,$08,$07,$01,$07
	DB	$C0,$88,$00,$01,$84,$00,$01,$05,$81,$06,$07,$0C,$12
	DB	$82,$13,$14,$18,$14,$18,$1E,$18,$1E,$1F,$20,$1F,$26
	DB	$81,$2B,$26,$1F,$1A,$13,$0E,$07,$02
	DB	$FF
S02
	DB	$DD,$8C,$6E,$18
	DB	$DD,$84,$6E,$18
	DB	$DD,$8C,$6E,$18
	DB	$DD,$84,$6E,$18
	DB	$DD,$8C,$6E,$18
	DB	$DD,$84,$6E,$18
	DB	$DD,$86,$6E,$18
	DB	$DD,$82,$6E,$18
	DB	$DD,$84,$70,$18
	DB	$DD,$84,$6E,$18

	DB	$DD,$8C,$6E,$11
	DB	$DD,$84,$6E,$11
	DB	$DD,$8C,$6E,$16
	DB	$DD,$84,$6E,$14
	DB	$DD,$8C,$6E,$13
	DB	$DD,$84,$6E,$13
	DB	$DD,$86,$6E,$13
	DB	$DD,$82,$6E,$13
	DB	$DD,$84,$70,$13
	DB	$DD,$84,$6E,$13

	DB	$DD,$8C,$6E,$18
	DB	$DD,$84,$6E,$18
	DB	$DD,$8C,$6E,$18
	DB	$DD,$84,$6E,$18
	DB	$DD,$8C,$6E,$18
	DB	$DD,$84,$6E,$18
	DB	$DD,$86,$6E,$18
	DB	$DD,$82,$6E,$18
	DB	$DD,$84,$70,$18
	DB	$DD,$84,$6E,$18

	DB	$DD,$8C,$6E,$11
	DB	$DD,$84,$6E,$11
	DB	$DD,$8C,$6E,$16
	DB	$DD,$84,$6E,$14
	DB	$DD,$8C,$6E,$13
	DB	$DD,$84,$6E,$13
	DB	$DD,$86,$6E,$13
	DB	$DD,$82,$6E,$13
	DB	$DD,$84,$70,$13
	DB	$DD,$84,$6E,$13

	DB	$DD,$8C,$6E,$18
	DB	$DD,$84,$6E,$18
	DB	$DD,$8C,$6E,$18
	DB	$DD,$84,$6E,$18
	DB	$DD,$8C,$6E,$18
	DB	$DD,$84,$6E,$18
	DB	$DD,$86,$6E,$18
	DB	$DD,$82,$6E,$18
	DB	$DD,$84,$70,$18
	DB	$DD,$84,$6E,$18

	DB	$DD,$8C,$6E,$0C
	DB	$DD,$84,$6E,$0C
	DB	$DD,$8C,$6E,$11
	DB	$DD,$84,$6E,$0F
	DB	$DD,$8C,$6E,$13
	DB	$DD,$84,$6E,$13
	DB	$DD,$86,$6E,$13
	DB	$DD,$82,$6E,$13
	DB	$DD,$84,$70,$11
	DB	$DD,$84,$6E,$0F
	DB	$FF
S03
	DB	$C2,$9C,$66,$24,$84,$18
	DB	$C2,$9C,$67,$24,$84,$18
	DB	$C2,$90,$66,$1D,$88,$22,$84,$20,$14
	DB	$C2,$84,$66,$1F,$20,$1F,$20,$13,$14,$13,$14
	DB	$FF
S04
	DB	$DF,$84,$71,$0C
	DB	$DF,$81,$71,$00,$E3
	DB	$DF,$84,$71,$02
	DB	$DF,$84,$71,$0C
	DB	$DF,$84,$71,$0C
	DB	$DF,$81,$71,$00,$E3
	DB	$DF,$84,$71,$02
	DB	$DF,$84,$71,$0C
	DB	$DF,$84,$71,$0C
	DB	$DF,$81,$71,$00,$E3
	DB	$DF,$84,$71,$02
	DB	$DF,$84,$71,$0C
	DB	$DF,$84,$71,$0C
	DB	$DF,$81,$71,$00,$E1
	DB	$DF,$82,$71,$0C
	DB	$DF,$84,$71,$06
	DB	$DF,$84,$71,$0C
;	DB	$C6,$81,$08,$0A,$0B,$0C,$0D,$0C,$0B,$0A
	DB	$FF


DR_TTLORC0	DB	$80,$05
	DB	$00,$FE
DR_TTLORC1	DB	$80,$06,$09
         	DB	$00,$FE
DR_TTLORC2	DB	$80,$07,$07,$07,$07,$07,$07,$07,$07,$5D
	DB	$00,$FE
DR_TTLORC3	DB	$80,$08
	DB	$00,$FE

S5D
	DB	$DD,$85,$6E,$0C,$E1
	DB	$FF	
S05
	DB	$C4,$82,$66,$24,$C2
	DB	$C4,$82,$25,$C2
	DB	$C4,$82,$29
	DB	$C4,$82,$28,$C2
	DB	$C4,$82,$24
	DB	$C4,$82,$25,$C2
	DB	$C4,$82,$27
	DB	$C4,$82,$25,$C2
	DB	$C4,$82,$24
	DB	$C4,$82,$22,$C2
	DB	$C4,$82,$24,$C2
	DB	$C4,$82,$24
	DB	$C4,$82,$24,$C2
	DB	$C4,$82,$24
	DB	$C4,$82,$24,$C2
	DB	$C4,$82,$24,$C2,$C2,$C2,$C2,$C2,$C2,$C2

	DB	$C4,$82,$18
	DB	$C4,$82,$18,$C2
	DB	$C4,$82,$18
	DB	$C4,$82,$18,$C2
	DB	$C4,$82,$18
	DB	$C4,$82,$18,$C2,$C2,$C2,$C2,$C2,$C2,$C2,$C2
	DB	$C4,$82,$0C
	DB	$C4,$82,$0C,$C2
	DB	$C4,$82,$0C
	DB	$C4,$82,$0C,$C2
	DB	$C4,$82,$0C
	DB	$C4,$82,$0C,$C2,$C2,$C2,$C2,$C2,$C2,$C2,$C2,$C2,$C2

	DB	$C1,$81,$3D,$3C,$31,$30,$31,$30,$25,$24
	DB	$1F,$1E,$82,$19,$18,$83,$14,$13,$84,$0D,$0C
	DB	$85,$08,$07,$86,$01,$00,$85,$01,$00,$84,$01,$00
	DB	$83,$01,$00,$82,$01,$00,$81,$01,$00,$01,$00,$01,$00,$E1
	DB	$FF
S06
	DB	$C4,$82,$6A,$18,$C2
	DB	$C4,$82,$19,$C2
	DB	$C4,$82,$1D
	DB	$C4,$82,$1C,$C2
	DB	$C4,$82,$18
	DB	$C4,$82,$19,$C2
	DB	$C4,$82,$1B
	DB	$C4,$82,$19,$C2
	DB	$C4,$82,$18
	DB	$C4,$82,$16,$C2
	DB	$C4,$82,$18,$C2
	DB	$C4,$82,$18
	DB	$C4,$82,$18,$C2
	DB	$C4,$82,$18
	DB	$C4,$82,$18,$C2
	DB	$C4,$82,$18,$C2,$C2,$C2,$C2,$C2,$C2,$C2

	DB	$C4,$82,$0C
	DB	$C4,$82,$0C,$C2
	DB	$C4,$82,$0C
	DB	$C4,$82,$0C,$C2
	DB	$C4,$82,$0C
	DB	$C4,$82,$0C,$C2,$C2,$C2,$C2,$C2,$C2,$C2,$C2
	DB	$C4,$82,$00
	DB	$C4,$82,$00,$C2
	DB	$C4,$82,$00
	DB	$C4,$82,$00,$C2
	DB	$C4,$82,$00
	DB	$C4,$82,$00,$C2,$C2,$C2,$C2,$C2,$C2,$C2,$C2
	DB	$FF
S07
	DB	$DD,$88,$6E,$18
	DB	$DD,$88,$6E,$18
	DB	$FF
S08
	DB	$C5,$88,$0F,$0E,$0D,$0C,$0B,$0A,$09,$08,$07,$06,$05,$04
	DB	$03,$02,$01,$00,$0F
	DB	$FF
S09
	DB	$C0,$81,$3D,$3C,$31,$30,$31,$30,$25,$24
	DB	$1F,$1E,$82,$19,$18,$83,$14,$13,$84,$0D,$0C
	DB	$85,$08,$07,$86,$01,$00,$85,$01,$00,$84,$01,$00
	DB	$83,$01,$00,$82,$01,$00,$81,$01,$00,$01,$00,$01,$00,$E1
	DB	$FF

ENTPASSJ0
	DB	$81,$0A
	DB	$FF,$00
ENTPASSJ1
	DB	$81,$0B,$71,$0A
	DB	$FF,$03
ENTPASSJ3
	DB	$80,12,12,12,12,12,12,12,13,12,12,12,13
	DB	$FF,$00

S0A
	DB	$C7,$88,$1F
	DB	$84,$18
	DB	$88,$1F
	DB	$84,$1E
	DB	$84,$1A
	DB	$84,$1B
	DB	$88,$1D
	DB	$84,$19
	DB	$8A,$18,$81,$19,$18
	DB	$88,$16
	DB	$88,$18
	DB	$84,$1F
	DB	$8C,$24
	DB	$88,$2B
	DB	$98,$2A
	DB	$81,$29,$27,$25,$24,$22,$20,$1F,$1E
	
	DB	$84,$1F
	DB	$84,$18
	DB	$84,$1F
	DB	$88,$20
	DB	$84,$1F
	DB	$84,$1E
	DB	$84,$1F
	DB	$84,$20
	DB	$84,$19
	DB	$84,$20
	DB	$88,$FD,$1F,$20,$22
	DB	$84,$24
	DB	$84,$FD,$2F,$25,$27
	DB	$84,$25
	DB	$84,$22
	DB	$84,$24
	DB	$84,$1F
	DB	$8C,$1E
	DB	$84,$1A
	DB	$84,$1B
	DB	$84,$1D
	DB	$84,$19
	DB	$82,$18,$81,$19,$18
	DB	$84,$16
	DB	$84,$13
	DB	$84,$12
	DB	$82,$0D,$81,$0F,$0D
	DB	$84,$0C
	DB	$94,$0A
	DB	$84,$0C
	DB	$82,$0D,$81,$0F,$0D
	DB	$84,$0A
	DB	$84,$0C
	DB	$88,$13
	DB	$88,$FD,$1F,$13,$14
	DB	$84,$13
	DB	$84,$12
	DB	$84,$13
	DB	$94,$0A
	DB	$84,$0C
	DB	$82,$0D,$81,$0F,$0D
	DB	$84,$0A
	DB	$84,$0C
	DB	$84,$13
	DB	$84,$14
	DB	$84,$0C
	DB	$84,$12
	DB	$84,$13
	DB	$84,$18
	DB	$81,$25,$24,$22,$20
	DB	$FF
S0B
	DB	$E6
	DB	$FF
S0C
	DB	$C5,$88,$0F
	DB	$C1,$84,$0F,$0F,$C0,$C1,$0E,$C1,$0D,$C1,$0C
	DB	$FF
S0D
	DB	$C5,$88,$0F,$C1,$84,$0E,$0D
	DB	$C5,$88,$0C,$C1,$84,$0B,$0A
	DB	$FF

HORRORD0	DB	$85,$0E,$0E,$0E,$0E,$11,$8C,$11
	DB	$FF,$00

HORRORN0	DB	$88,$0E,$0E,$0E,$0E,$11,$8F,$11
	DB	$FF,$00

HORRORD1
	DB	$85,$0F,$0F,$10,$10,$12,$8C,$12
	DB	$FF,$00

HORRORN1	DB	$88,$0F,$0F,$10,$10,$12,$8F,$12
	DB	$FF,$00

S0E
	DB	$C7,$8C,$0C
	DB	$C7,$94,$0C
	DB	$C7,$8C,$0C
	DB	$C7,$8C,$08
	DB	$C7,$88,$08
	DB	$C7,$8C,$07
	DB	$C7,$8C,$07
	DB	$C7,$82,$07,$07,$84,$07
	DB	$C7,$84,$06
	DB	$C7,$82,$03,$0F,$1B,$06,$12,$1E
	DB	$C7,$84,$07,$82,$13,$12,$0F,$0E,$08,$07
	DB	$FF
S0F
	DB	$C7,$8C,$14
	DB	$C7,$94,$13
	DB	$C7,$8C,$12
	DB	$C7,$8C,$0F
	DB	$C7,$84,$0E
	DB	$C7,$81,$0C,$0D,$0E,$0F
	DB	$C7,$8C,$0E
	DB	$C7,$8C,$0C
	DB	$C7,$81,$06,$07,$08,$0C
	DB	$C7,$82,$0E
	DB	$C7,$82,$0F
	DB	$C7,$88,$FD,$1F,$0E,$0F
	DB	$C7,$84,$0E,$0C,$0B,$82,$0C,$81,$0B,$0C,$88,$0E
	DB	$FF
S10
	DB	$C9,$8C,$64,$0C
	DB	$C9,$94,$60,$0C
	DB	$C9,$8C,$6C,$0C
	DB	$C9,$8C,$61,$08
	DB	$C9,$84,$6D,$08,$81,$06,$07,$08,$09
	DB	$C9,$8C,$6E,$07
	DB	$C9,$90,$65,$03
	DB	$C9,$82,$6E,$07
	DB	$C9,$82,$62,$07
	DB	$C9,$86,$61,$08
	DB	$C9,$86,$6D,$08
	DB	$C9,$84,$63,$03
	DB	$C9,$84,$63,$02
	DB	$C9,$84,$6E,$07
	DB	$C9,$88,$61,$07
	DB	$FF
S11
	DB	$C7,$82,$0C,$0D,$11,$13,$14,$18,$19,$1B
	DB	$1D,$18,$20,$1F,$1D,$18,$14,$13
	DB	$11,$12,$16,$18,$19,$22,$20,$1E
	DB	$1D,$1E,$1D,$19,$81,$18,$19,$18,$19,$84,$18
	DB	$82,$19,$1B,$1D,$19,$18,$1C,$1D,$18
	DB	$17,$1C,$1D,$17,$16,$1C,$1D,$15
	DB	$14,$1C,$1D,$14,$13,$1C,$1D,$13
	DB	$12,$1C,$1D,$12,$81,$11,$18,$1D,$24,$84,$29
	DB	$FF
S12
	DB	$E4
	DB	$C8,$82,$0C,$0D,$11,$13,$14,$18,$19,$1B
	DB	$1D,$18,$20,$1F,$1D,$18,$14,$13
	DB	$11,$12,$16,$18,$19,$22,$20,$1E
	DB	$1D,$1E,$1D,$19,$81,$18,$19,$18,$19,$84,$18
	DB	$82,$19,$1B,$1D,$19,$18,$1C,$1D,$18
	DB	$17,$1C,$1D,$17,$16,$1C,$1D,$15
	DB	$14,$1C,$1D,$14,$13,$1C,$1D,$13
	DB	$12,$1C,$1D,$12,$81,$11,$18,$1D,$24
	DB	$FF

LEVEL10	DB	$8D,$14
	DB	$FF,$00
LEVEL11	DB	$8D,$13,$71,$14
	DB	$FF,$03

S13
	DB	$E2
	DB	$FF
S14
	DB	$C9,$A0,$6F,$00,$03,$06,$98,$09,$84,$0A,$0B,$A0,$0C,$0F,$12,$98,$15,$84,$16,$17
	DB	$C7,$81,$24,$25,$26,$27,$2C,$2D,$2E,$2F
	DB	$30,$31,$32,$33,$38,$39,$3A,$3B
	DB	$3C,$36,$30,$2A,$29,$27,$25,$24
	DB	$22,$20,$1F,$1E,$1D,$1B,$19,$18
	DB	$82,$16,$83,$19,$84,$18,$14,$13,$0D,$0C,$0A
	DB	$82,$0C,$0D,$81,$0C,$0D,$0C,$0D
	DB	$82,$0C,$0D,$81,$0C,$0D,$0C,$0D
	DB	$82,$0C,$0D,$81,$0C,$0D,$0C,$0D
	DB	$82,$0C,$0D,$81,$0D,$12,$13,$17
	DB	$84,$18
	DB	$82,$16
	DB	$82,$14
	DB	$82,$13
	DB	$82,$11 
	DB	$82,$13
	DB	$82,$16
	DB	$82,$14
	DB	$82,$13
	DB	$82,$11
	DB	$82,$14
	DB	$84,$13
	DB	$84,$0C
	DB	$84,$18
	DB	$82,$19
	DB	$82,$1B
	DB	$82,$1C
	DB	$81,$1B,$1C
	DB	$82,$19
	DB	$82,$18
	DB	$82,$17
	DB	$81,$14,$17
	DB	$82,$13
	DB	$82,$20
	DB	$88,$FD,$41,$1F,$18
	DB	$FF
LEVEL20
	DB	$84,$15
	DB	$FF,$00
LEVEL21
	DB	$84,$16,$17
	DB	$FF,$00

S15
	DB	$C9,$82,$70,$18,$CA,$1C
	DB	$C9,$82,$70,$19,$CA,$18
	DB	$C9,$82,$70,$1F,$CA,$19
	DB	$C9,$82,$70,$1E,$CA,$1F
	DB	$C9,$82,$70,$1D,$CA,$1E
	DB	$C9,$82,$70,$19,$CA,$1D
	DB	$C9,$82,$70,$16,$CA,$19
	DB	$C9,$82,$70,$1C,$CA,$16
	DB	$FF
S16
	DB	$F0,$F0,$F0,$F0,$F0,$F0,$F0,$F0
	DB	$C7,$8C,$FD,$08,$0A,$0C
	DB	$88,$0D
	DB	$82,$0C,$81,$0D,$0C
	DB	$84,$0B,$0C
	DB	$88,$FD,$18,$13,$14
	DB	$86,$13,$81,$14,$13
	DB	$84,$12
	DB	$88,$13,$81,$18,$1F,$24,$2B

	DB	$C7,$8C,$FD,$08,$0A,$0C
	DB	$88,$0D
	DB	$84,$0B,$0C,$08,$06,$07
	DB	$82,$0F,$81,$11,$0F,$84,$0E
	DB	$81,$0F,$11,$8A,$13,$81,$1A,$1F,$26,$2B

	DB	$C7,$84,$0C,$82,$18,$0C,$24,$18
	DB	$84,$0D,$82,$19,$0D
	DB	$82,$0C,$81,$0D,$0C
	DB	$84,$0B,$0C
	DB	$8C,$FD,$1F,$14,$16,$18
	DB	$86,$19,$81,$1B,$19

	DB	$C7,$84,$17,$18,$81,$19,$18,$17,$18,$19,$18,$17,$18
	DB	$C7,$84,$19,$18,$81,$17,$18,$19,$18,$17,$16,$14,$16
	DB	$C7,$90,$18
	DB	$81,$16,$14,$13,$12,$11,$0F,$0D,$0C
	DB	$0B,$0A,$08,$07,$06,$05,$03,$01
	DB	$98,$00,$81,$0D,$0C,$0A,$08,$07,$06,$05,$03
	DB	$98,$01,$81,$0F,$0D,$0C,$0A,$08,$07,$06,$05
	DB	$98,$03,$81,$11,$0F,$0D,$0C,$0A,$08,$07,$06
	DB	$98,$05,$81,$13,$11,$0F,$0D,$0C,$07,$05,$03
	DB	$FF
S17
	DB	$84,$00,$82,$00,$84,$01,$82,$03,$84,$01,$82,$00
	DB	$84,$01,$82,$03,$05,$07,$08,$0A
	DB	$84,$0C,$82,$0C,$84,$0D,$82,$0F,$84,$0D,$82,$0C
	DB	$84,$0D,$82,$0F,$11,$13,$14,$16
	DB	$84,$18,$82,$18,$84,$19,$82,$1B,$1D,$1F,$20,$1F,$1D,$1B
	DB	$22,$25,$29,$2B
	DB	$98,$30,$81,$2E,$30,$2C,$30,$2B,$30,$29,$30
	DB	$82,$27,$25,$24,$22,$25,$24,$1F,$20,$1F,$18,$19,$1B
	DB	$82,$19,$18,$16,$18
	DB	$1B,$19,$18,$16,$19,$18,$13,$14,$13,$0C,$0D,$0F,$0D,$0C,$0A,$0D
	DB	$A0,$FD,$F1,$0C,$0A
	DB	$A0,$FD,$F1,$08,$06
	DB	$A0,$FD,$F1,$07,$05
	DB	$A0,$FD,$F1,$01,$03
	DB	$FF

LEVEL30
	DB	$87,$18
	DB	$FF,$00
LEVEL31
	DB	$87,$19,$71,$18
	DB	$FF,$03

S18
	DB	$C7,$84,$0C,$13,$FD,$0A,$12,$13,$13,$FD,$0A,$12,$13
	DB	$14,$FD,$0A,$13,$14,$14,$0C,$12,$FD,$0A,$11,$12,$12
	DB	$FD,$0A,$10,$11,$12,$FD,$0A,$10,$11,$82,$0D,$81,$0F,$0D
	DB	$84,$0C,$13,$FD,$0A,$12,$13,$13,$FD,$0A,$12,$13,$14
	DB	$FD,$0A,$13,$14,$14,$0C,$12
	DB	$FD,$0A,$11,$12,$12,$11,$82,$0F,$11,$12,$11,$0D,$0A
	DB	$82,$0C,$0D,$0C,$0A,$0C,$0A,$08,$0A,$84,$07
	DB	$82,$13,$14,$16,$14,$13,$81,$05,$06
	DB	$82,$0C,$0D,$0C,$0A,$0C,$0A,$08,$0A,$05,$07,$08,$07
	DB	$0C,$13,$18,$1F

	DB	$18,$19,$18,$16,$18,$16,$14,$16,$84,$13
	DB	$82,$1F,$20,$FD,$0F,$21,$22,$20,$1F,$81,$11,$12

	DB	$18,$19,$18,$16,$18,$16,$14,$16,$13,$14,$13,$11,$10,$0D
	DB	$0C,$08,$07,$08,$07,$05,$07,$01,$03,$05,$07,$00,$01,$05
	DB	$84,$07
	DB	$81,$18,$19,$18,$16,$18,$16,$14,$16,$13,$14,$13,$11,$10,$0D
	DB	$0C,$08,$07,$08,$07,$05,$07,$01,$03,$05,$07,$00,$01,$05
	DB	$84,$07

	DB	$82
	DB	$18,$19,$18,$16,$18,$16,$14,$16,$13,$14,$13,$11,$10,$0D
	DB	$0C,$08,$07,$08,$07,$05,$07,$01,$03,$05,$07,$00,$81,$01,$05
	DB	$82,$07,$82,$0A,$0C,$0D,$0A
	DB	$A0,$FD,$04,$0A,$0C,$0A,$FD,$04,$06,$08,$07,$FD,$04,$01,$00
	DB	$FD,$04,$00,$01,$FD,$04,$01,$00,$06
	DB	$FF
S19
	DB	$E6
	DB	$FF
GUARD10
	DB	$8C,$1A,$1B,$1B,$1E,$1E
	DB	$FF,$02
GUARD11
	DB	$8C,$1C,$1D,$1D,$1F,$1F
	DB	$FF,$02

S1A
	DB	$C7,$84,$0C
	DB	$FF
S1B
	DB	$84
	DB	$12,$12,$12,$13,$13,$13,$13,$0C
	DB	$C7,$84,$0F,$0F,$0F,$0E,$0E,$0E,$0E,$0C,$12
	DB	$12,$12,$13,$13,$13,$13,$0C,$16,$16,$16,$15,$15,$15,$14,$13
	DB	$FF
S1C
	DB	$DE,$84,$6F,$07
	DB	$FF
S1D
	DB	$DE
	DB	$84
	DB	$6F,$0C,$0C,$0C
	DB	$0C,$0C,$0C,$0C
	DB	$07
	DB	$08,$08,$08
	DB	$08,$08,$08,$08
	DB	$07

	DB	$0C,$0C,$0C
	DB	$0C,$0C,$0C,$0C
	DB	$07
	DB	$0F,$0F,$0F
	DB	$0E,$0E,$0E,$0D,$0C
	DB	$FF	
S1E
	DB	$C7,$98,$12
	DB	$88,$0F
	DB	$98,$FD,$0C,$0C,$0E
	DB	$86,$0C,$81,$0E,$0F
	DB	$98,$12
	DB	$86,$0F,$81,$11,$0F
	DB	$88,$FD,$0C,$0C,$0E
	DB	$88,$0C
	DB	$88,$0F
	DB	$88,$13

	DB	$90,$18
	DB	$90,$1B
	DB	$90,$FD,$08,$18,$1A
	DB	$90,$1F
	DB	$FF
S1F
	DB	$C9,$98,$6C,$0C
	DB	$88,$61,$08
	DB	$98,$6E,$07
	DB	$88,$65,$03
	DB	$98,$6C,$0C
	DB	$88,$61,$08
	DB	$88,$6E,$07
	DB	$88,$65,$03
	DB	$88,$62,$07
	DB	$88,$60,$0C

	DB	$90,$64,$0C
	DB	$90,$60,$11
	DB	$90,$61,$13
	DB	$90,$64,$17
	DB	$FF

DRACULA0
	DB	$83,$70,$20,$22,$23,$71,$20
	DB	$FF,$00
DRACULA1
	DB	$83,$70,$21,$23,$71,$22,$21
	DB	$FF,$00

S20
	DB	$C7,$8C,$FD,$18,$0A,$0C
	DB	$C7,$8C,$FD,$8F,$08,$06
	DB	$C7,$88,$FD,$08,$06,$07
	DB	$C7,$8C,$FD,$08,$0D,$0F
	DB	$C7,$8A,$FD,$08,$0C,$0D,$81,$0F,$0D
	DB	$C7,$88,$FD,$08,$09,$0A
	DB	$C7,$8C,$FD,$08,$0A,$0C
	DB	$C7,$8C,$FD,$08,$14,$16
	DB	$C7,$86,$FD,$08,$13,$14
	DB	$C7,$81,$16,$14
	DB	$C7,$A0,$FD,$08,$11,$13
	DB	$C7,$8C,$FD,$08,$0A,$0C
	DB	$C7,$8C,$FD,$8F,$08,$06
	DB	$C7,$88,$FD,$08,$06,$07
	DB	$C7,$8C,$FD,$08,$0D,$0F
	DB	$C7,$8A,$FD,$08,$0C,$0D,$81,$0F,$0D
	DB	$C7,$88,$FD,$08,$09,$0A
	DB	$C7,$88,$FD,$08,$0A,$0C
	DB	$C7,$84,$18
	DB	$C7,$88,$FD,$08,$18,$19
	DB	$C7,$84,$18
	DB	$C7,$84,$16
	DB	$C7,$84,$18
	DB	$C7,$82,$1F,$1E,$20,$1F,$25,$24,$2C,$2B
	DB	$C7,$90,$FD,$08,$2E,$30
	DB	$FF
S21
	DB	$C9,$84,$79,$18,$18,$18,$18,$18,$18,$19,$18
	DB	$C9,$84,$79,$17,$17,$17,$17,$17,$17,$16,$17
	DB	$C9,$84,$79,$18,$18,$18,$18,$18,$18,$16,$14
	DB	$C9,$84,$79,$13,$13,$13,$13,$14,$13,$12,$13
	DB	$C9,$84,$79,$18,$18,$18,$18,$18,$18,$19,$18
	DB	$C9,$84,$79,$17,$17,$17,$17,$17,$17,$16,$17
	DB	$C9,$84,$79,$18,$18,$18,$18,$18,$18,$19,$18
	DB	$C9,$84,$79,$24,$24,$25,$27,$24,$18,$0C,$00
	DB	$FF
S22
	DB	$C7,$8C,$FD,$08,$05,$07
	DB	$88,$08
	DB	$84,$07,$06,$07
	DB	$88,$06,$03
	DB	$86,$02,$81,$03,$02
	DB	$88,$00
	DB	$8C,$FD,$08,$05,$07
	DB	$88,$08
	DB	$82,$07,$81,$08,$07
	DB	$84,$06,$07
	DB	$94,$0D,$82,$0F,$0D
	DB	$82,$0C,$0D,$0C,$08

	DB	$C7,$8C,$FD,$08,$05,$07
	DB	$88,$08
	DB	$84,$07,$06,$07
	DB	$88,$06,$03
	DB	$86,$02,$81,$03,$02
	DB	$88,$00
	DB	$84,$02
	DB	$84,$07
	DB	$82,$08,$81,$0A,$08
	DB	$84,$07
	DB	$84,$14
	DB	$84,$16,$14,$11
	DB	$88,$12,$1E,$8A,$FD,$41,$2A,$2F
	DB	$FF
S23
	DB	$E6
	DB	$FF

GAMEOVER0
		DB	$84,$78,$25,$25,$24	;73
		DB	$00,$FE
GAMEOVER1
		DB	$84,$77,$25,$24
		DB	$00,$FE
GAMEOVER2
		DB	$90,$24
		DB	$00,$FE
GAMEOVER3
		DB	$80,$26
		DB	$00,$FE

S24
		DB	$C0,$81,$38,$37,$31,$30
		DB	$82,$2C,$2B
		DB	$83,$25,$24
		DB	$84,$20,$1F
		DB	$85,$19,$18
		DB	$86,$14,$13
		DB	$87,$0D,$0C
		DB	$88,$08,$07
		DB	$98,$01,$81,$31,$2C,$25,$20,$19,$14,$08,$01
		DB	$81,$30,$2B,$24,$1F,$18,$13,$0C,$07
		DB	$82,$00
		DB	$FF
S25
		DB	$E4
		DB	$FF
S26
		DB	$C5,$84,$06
		DB	$C5,$84,$06
		DB	$C5,$86,$06
		DB	$C5,$88,$06
		DB	$C5,$8A,$06
		DB	$C5,$8C,$06
		DB	$C5,$8E,$06
		DB	$C5,$90,$06
		DB	$C5,$98,$06,$88,$05
		DB	$C5,$90,$04
		DB	$FF

GAMECOMPL0
	DB	$8D,$27
	DB	$00,$FE
GAMECOMPL1
	DB	$8D,$28
	DB	$00,$FE
GAMECOMPL2
	DB	$8D,$29
	DB	$00,$FE
GAMECOMPL3
	DB	$80,$2A
	DB	$00,$FE

S27
	DB	$C3,$84,$13
	DB	$18,$1C,$8C,$1A
	DB	$82,$18,$81,$1A,$18,$84,$16,$15,$16,$18
	DB	$84,$11,$16,$82,$15,$81,$16,$15,$84,$11,$0E,$10,$11,$13
	DB	$88,$FD,$4F,$0C,$0A
	DB	$88,$0A
	DB	$82,$11,$0E
	DB	$84,$10,$11,$13
	DB	$84,$FD,$1F,$18,$1A,$C7,$13
	DB	$C3,$88,$16
	DB	$82,$15
	DB	$81,$16,$15

	DB	$84,$13,$18,$1C,$8C,$FD,$1F,$1C,$1D
	DB	$84,$1C,$1A,$18,$1C,$1F
	DB	$84,$22,$C7,$16
	DB	$C3,$8C,$FD,$1F,$21,$22
	DB	$84,$24,$C7,$0C,$00
	DB	$C3,$84,$FD,$1F,$22,$24,$C7,$18,$0C
	DB	$C3,$84,$22
	DB	$84,$FD,$1F,$22,$24
	DB	$FF
S28
	DB	$CC,$88,$64,$10,$C9,$84
	DB	$CC,$8C,$64,$0E
	DB	$CC,$84,$64,$0E,$C9
	DB	$CC,$8C,$63,$0C,$84
	DB	$CC,$84,$64,$0E
	DB	$CC,$84,$63,$0C
	DB	$CC,$84,$61,$0A
	DB	$CC,$84,$63,$05
	DB	$CC,$88,$63,$07,$C9,$84
	DB	$CC,$8C,$61,$0A
	DB	$CC,$84,$61,$0A,$C9
	DB	$CC,$88,$61,$0C,$C9,$84
	DB	$CC,$8C,$61,$0A
	DB	$CC,$84,$64,$0E,$63,$11

	DB	$CC,$88,$63,$13,$C9,$84
	DB	$CC,$8C,$61,$16
	DB	$CC,$84,$61,$16,$C9

	DB	$CC,$84,$61,$18,$C9
	DB	$CC,$84,$61,$18
	DB	$CC,$84,$64,$1A,$C9
	DB	$CC,$8C,$64,$1A
	DB	$CC,$84,$64,$1C,$C9,$C2
	DB	$CC,$84,$64,$1C,$C9,$C2
	DB	$CC,$84,$63,$1D
	DB	$CC,$84,$63,$1F
	DB	$FF
S29
	DB	$DD,$88,$72,$0C
	DB	$DD,$84,$73,$0C
	DB	$DD,$8C,$72,$07
	DB	$DD,$84,$73,$07
	DB	$DD,$84,$72,$07
	DB	$DD,$88,$72,$05
	DB	$DD,$84,$73,$05
	DB	$DD,$88,$72,$0A
	DB	$DD,$84,$72,$09
	DB	$DD,$84,$73,$05
	DB	$DD,$84,$72,$02
	DB	$DD,$84,$72,$00
	DB	$DD,$84,$6D,$04
	DB	$DD,$84,$73,$07
	DB	$DD,$88,$72,$0A
	DB	$DD,$84,$72,$0A
	DB	$DD,$84,$73,$09
	DB	$DD,$84,$72,$07
	DB	$DD,$84,$72,$00
	DB	$DD,$84,$6D,$04
	DB	$DD,$84,$73,$07
	DB	$DD,$84,$72,$0E
	DB	$DD,$84,$6D,$02
	DB	$DD,$84,$72,$0A
	DB	$DD,$84,$73,$0A
	DB	$DD,$82,$6D,$09
	DB	$DD,$82,$07

	DB	$DD,$88,$72,$0C
	DB	$DD,$84,$73,$0C
	DB	$DD,$8C,$72,$07
	DB	$DD,$84,$73,$04
	DB	$DD,$84,$72,$02
	DB	$DD,$84,$72,$00
	DB	$DD,$84,$6D,$04
	DB	$DD,$84,$73,$07
	DB	$DD,$84,$72,$0A
	DB	$DD,$84,$6D,$0A
	DB	$DD,$84,$72,$0A
	DB	$DD,$84,$73,$09
	DB	$DD,$84,$6D,$07
	DB	$DD,$84,$73,$00,$6D,$04,$72,$07
	DB	$DD,$84,$73,$0C,$6D,$10,$72,$13
	DB	$DD,$84,$73,$0E,$10
	DB	$FF
S2A
	DB	$CD,$84,$7C,$03
	DB	$CD,$84,$7C,$01
	DB	$DF,$84,$6D,$04
	DB	$CD,$84,$7C,$03
	DB	$CD,$84,$7C,$01
	DB	$CD,$84,$7C,$01
	DB	$DF,$84,$6D,$04
	DB	$CD,$84,$7C,$03
	DB	$CD,$84,$7C,$03
	DB	$CD,$84,$7C,$01
	DB	$DF,$84,$6D,$04
	DB	$CD,$84,$7C,$03
	DB	$CD,$84,$7C,$01
	DB	$CD,$84,$7C,$03
	DB	$DF,$84,$6D,$04
	DB	$CD,$84,$7C,$03
	DB	$CD,$84,$7C,$03
	DB	$CD,$84,$7C,$01
	DB	$DF,$84,$6D,$04
	DB	$CD,$84,$7C,$03
	DB	$CD,$84,$7C,$01
	DB	$CD,$84,$7C,$03
	DB	$DF,$84,$6D,$04
	DB	$CD,$84,$7C,$03
	DB	$CD,$84,$7C,$03
	DB	$CD,$84,$7C,$01
	DB	$DF,$84,$6D,$04
	DB	$CD,$84,$7C,$03
	DB	$CD,$84,$7C,$01
	DB	$CD,$84,$7C,$03
	DB	$DF,$84,$6D,$04
	DB	$CD,$84,$7C,$03
	DB	$CD,$84,$7C,$03
	DB	$CD,$84,$7C,$01
	DB	$DF,$84,$6D,$04
	DB	$CD,$84,$7C,$03
	DB	$CD,$84,$7C,$01
	DB	$CD,$84,$7C,$01
	DB	$DF,$84,$6D,$04
	DB	$CD,$84,$7C,$03
	DB	$CD,$84,$7C,$03
	DB	$CD,$84,$7C,$01
	DB	$DF,$84,$6D,$04
	DB	$CD,$84,$7C,$03
	DB	$CD,$84,$7C,$01
	DB	$CD,$84,$7C,$03
	DB	$DF,$84,$6D,$04
	DB	$CD,$84,$7C,$03
	DB	$DF,$84,$6D,$04
	DB	$CD,$84,$7C,$01
	DB	$CD,$84,$7C,$03
	DB	$DF,$84,$6D,$04
	DB	$CD,$84,$7C,$01
	DB	$CD,$84,$7C,$03
	DB	$DF,$84,$6D,$04
	DB	$DF,$84,$6D,$04
	DB	$FF
	DB	$CD,$84,$7A,$08,$06,$04,$08,$05,$05,$04,$05
	DB	$CD,$84,$08,$05,$04,$08,$08,$08,$04,$08
	DB	$CD,$84,$08,$05,$04,$08,$05,$08,$04,$08
	DB	$CD,$84,$08,$06,$04,$08,$05,$08,$04,$08
	DB	$CD,$84,$08,$05,$04,$08,$05,$05,$04,$08
	DB	$CD,$84,$08,$05,$04,$08,$05,$08,$04,$08
	DB	$CD,$84,$04,$05,$08,$04,$05,$08,$04,$04
	DB	$FF
LVLCOMPL0
	DB	$8C,$2B
	DB	$00,$FE
LVLCOMPL1
	DB	$8C,$2C
	DB	$00,$FE
LVLCOMPL2
	DB	$8E,$2D
	DB	$00,$FE
LVLCOMPL3
	DB	$80,$2E
	DB	$00,$FE

S2B
	DB	$CB,$82,$0E,$C7,$02
	DB	$CB,$82,$0E
	DB	$CB,$82,$0E,$C7,$02
	DB	$CB,$82,$0E
	DB	$CB,$82,$11,$C7,$02
	DB	$CB,$82,$0F,$C7,$03
	DB	$CB,$82,$0E,$C7,$02
	DB	$CB,$82,$0C
	DB	$CB,$82,$0F,$C7,$02,$02
	DB	$CB,$8A,$0E
	DB	$CB,$82,$02
	DB	$CB,$82,$02
	DB	$CB,$82,$02
	DB	$CB,$83,$02
	DB	$FF
S2C
	DB	$CC,$82,$66,$0E,$C9
	DB	$CC,$82,$0E
	DB	$CC,$82,$0E,$C9
	DB	$CC,$82,$0E
	DB	$CC,$82,$11,$C9
	DB	$CC,$82,$0F,$C9
	DB	$CC,$82,$0E,$C9
	DB	$CC,$82,$0C
	DB	$CC,$82,$0F,$C9,$C9
	DB	$CC,$8A,$0E
	DB	$CC,$82,$02
	DB	$CC,$82,$02
	DB	$CC,$82,$02
	DB	$CC,$83,$02
	DB	$FF
S2D
	DB	$DD,$84,$72,$0C
	DB	$DD,$82,$72,$0C
	DB	$DD,$82,$72,$0C
	DB	$DD,$82,$73,$0C
	DB	$DD,$82,$72,$0C
	DB	$DD,$84,$72,$0F
	DB	$DD,$84,$72,$0D
	DB	$DD,$84,$72,$0C
	DB	$DD,$82,$73,$0A
	DB	$DD,$86,$72,$0D
	DB	$DD,$88,$72,$0C
	DB	$DD,$82,$73,$0C
	DB	$DD,$82,$72,$0C
	DB	$DD,$82,$72,$0C
	DB	$DD,$82,$72,$0C
	DB	$DD,$83,$72,$0C
	DB	$FF
S2E
	DB	$CD,$82,$7C,$03
	DB	$CD,$82,$7C,$01
	DB	$CD,$82,$7C,$03
	DB	$CD,$82,$7C,$03
	DB	$DF,$82,$6D,$04
	DB	$CD,$82,$7C,$03
	DB	$CD,$82,$7C,$03
	DB	$CD,$82,$7C,$01
	DB	$CD,$82,$7C,$03
	DB	$CD,$82,$7C,$01
	DB	$CD,$82,$7C,$03
	DB	$CD,$82,$7C,$01
	DB	$DF,$82,$6D,$04
	DB	$CD,$82,$7C,$03
	DB	$CD,$82,$7C,$01
	DB	$CD,$82,$7C,$01
	DB	$CD,$82,$7C,$03
	DB	$CD,$82,$7C,$01
	DB	$CD,$82,$7C,$01
	DB	$CD,$82,$7C,$01
	DB	$DF,$82,$6D,$04
	DB	$CD,$82,$7C,$03
	DB	$CD,$82,$7C,$03
	DB	$CD,$82,$7C,$03
	DB	$CD,$83,$7C,$03
	DB	$FF
INVINCIB2
	DB	$9B,$2F,$9A,$2F,$99,$2F,$98,$2F
	DB	$FF,$00
S2F
	DB	$C2,$81,$70,$0C,$00,$0D,$01,$0C,$00,$11,$05
	DB	$FF
LOOSELIF2
	DB	$8C,$30,$00	;86
	DB	$FE
S30
	DB	$C9,$81,$70,$27,$26,$24,$1F,$1B,$1A,$18,$13
	DB	$82,$0C,$01,$84,$00
	DB	$FF
VANHELS0
	DB	$84,$31
	DB	$00,$FE
VANHELS1
	DB	$84,$32
	DB	$00,$FE

S31
	DB	$C7,$88,$00,$02,$03,$05
	DB	$C7,$82,$07,$84,$07,$07,$07,$07,$0C,$0E,$86,$11
	DB	$C7,$94,$13,$82,$07,$06,$84,$05,$03,$00,$8C,$01
	DB	$FF
S32
	DB	$E4
	DB	$C9,$88,$7B,$13
	DB	$C9,$88,$7B,$15
	DB	$C9,$88,$7B,$16
	DB	$C9,$84,$7B,$18
	DB	$C9,$82,$1A,$84,$1A,$1A,$1A,$1A,$1A,$1A,$86,$1A
	DB	$C9,$94,$1A,$82,$0E,$0D,$84,$0C,$0A,$07,$8C,$08
	DB	$FF
			     
;----------------------------------------------------------------------


SWRDSWISH3	DB	$33,$00,$FE	 
S33	DB	$CF,$90,$7C,$04
	DB	$FF

THROWROCK3	DB	$34,$00,$FE

S34	DB	$D1,$88,$7C,$0A
	DB	$FF

LOBAXE3	DB	$35,$00,$FE

S35	DB	$C9,$81,$7C,3,2,1,2,3,2,1,2,3,2,1,2,3,2,1,0,$E1
	DB	$FF

LOBTORCH3	DB	$36,$00,$FE

S36	DB	$C9,$81,$7C,$06,$05,$06,$05,$04,$05,$04,$03,$04,$03,$02,$01,$00,$E1,$FF

TORCHSPL2	DB	$8C,$38,$00,$FE
TORCHSPL3	DB	$37,$00,$FE

S37	DB	$C5,$94,$0E
	DB	$FF

S38	DB	$D2,$87,$7D,$00
	DB	$FF

TRPLROCK3	DB	$39,$39,$39,$00,$FE

S39	DB	$C7,$81,7,6,5,4,3,2,1,0
	DB	$FF

JUMPER12	DB	$88,$3A,$00,$FE

S3A	DB	$D3,$88,$7E,$00
	DB	$FF

LANDER12	DB	$80,$3B,$00,$FE

S3B	DB	$D4,$8A,$7F,$00
	DB	$FF

HARDLAND2	DB	$80,$3C,$00,$FE
HARDLAND3	DB	$3D,$00,$FE

S3C	DB	$D2,$89,$7F,$08
	DB	$FF
S3D
	DB	$C5,$90,$0D
	DB	$FF

AAARGH2	DB	$80,$3E,$00,$FE

S3E	DB	$D4,$81,$7F,$08,$0A,$0D,$10,$12,$11,$10,$0F,$0D,$0B,$09,$07,$05
	DB	$04,$03,$02,$01,$00,$E1,$FF

SWITCHON2	DB	$98,$3F,$00,$FE

S3F	DB	$D4,$82,$60,$07,$0B,$0F
	DB	$FF

SWITCHOF2	DB	$98,$40,$00,$FE

S40	DB	$D4,$82,$60,$0F,$0B,$07
	DB	$FF

MECHWHIR2	DB	$8C,$41,$42,$FF,$02

S41	DB	$C2,$81,$7E,1,3,5,7,9,11
	DB	$FF

S42	DB	12,12,13,12,13,13,12,13
	DB	$FF

NMIKILLED2	DB	$8C,$43,$00,$00,$FE

S43	DB	$D2,$88,$7F,$03
	DB	$FF

PINGPICK2	DB	$80,$44,$00,$FE

S44	DB	$D7,$82,$30
	DB	$FF

BLOCKCRMB3	DB	$45,$00,$FE

S45	DB	$D8,$A0,$0F
	DB	$FF

SCCCTING2	DB	$97,$46,$00,$FE    ;8B
SCCCTING3	DB	$47,$00,$FE

S46	DB	$E3,$DA,$83,$38
	DB	$FF

S47	DB	$D9,$88,$02
	DB	$FF


SCCCTUNG2	DB	$8C,$46,$00,$FE
SCCCTUNG3	DB	$81,$47,$00,$FE


PHUTROCK2	DB	$8C,$48,$00,$FE
PHUTROCK3	DB	$49,$00,$FE

S49	DB	$CD,$88,$7C,$0D
	DB	$FF

S48	DB	$CD,$81,$70,$06,$03,$01,$00,$E1
	DB	$FF

RESTPOIN2	DB	$90,$4A,$00,$FE	;84

S4A	DB	$C7,$82,$24,$25,$2A,$84,$30,$82,$2A,$84,$30,$81,$2E,$2A,$22,$1E,$19,$12,$0D,$0A,$01
	DB	$82,$00
	DB	$FF

WOBBWOBB2	DB	$92,$4B,$4B,$4B,$4B,$00,$FE
WOBBWOBB3	DB	$4C,$4C,$4C,$4C,$00,$FE

S4B	DB	$C7,$81,$00,$02,$01,$03
	DB	$FF
S4C	DB	$C7,$81,$06,$04,$06,$05
	DB	$FF
S4D	DB	$E1
	DB	$FF

SUPRPING2	DB	$8C,$4E,$00,$FE

S4E	DB	$DB,$90,$60,$1E
	DB	$FF

MEGAPING2	DB	$8C,$4F,$00,$FE

S4F	DB	$DB,$90,$61,$24
	DB	$FF

EXTRALIF2	DB	$8C,$50,$00,$FE

S50	DB	$DB,$90,$62,$16
	DB	$FF

CONTCRDT2	DB	$8C,$51,$00,$FE

S51	DB	$DB,$90,$63,$2D
	DB	$FF

WARN20SC2	DB	$8C,$52,$00,$FE

S52	DB	$DB,$81,$64,$27,$24,$27,$24,$27,$24,$27,$87,$24
	DB	$FF

WARN10SC2	DB	$92,$5C,$00,$FE   ;86

S5C	DB	$DB,$81,$64,$27,$24,$27,$24,$27,$24,$27,$8C,$24
	DB	$FF

COUNTDWN2	DB	$8C,$53,$00,$FE

S53	DB	$DB,$84,$65,$2A
	DB	$FF

TIMEOUT2	DB	$8C,$54,$00,$FE

S54	DB	$DB,$86,$60,$13,$12,$11,$10,$90,$66,$0F
	DB	$FF

BONUSCNT2	DB	$8C,$55,$00,$FE

S55	DB	$DB,$92,$67,$11
	DB	$FF

BONUSPNG2	DB	$56,$00,$FE

S56	DB	$DB,$90,$68,$29
	DB	$FF

EXPLOSIO2	DB	$8C,$57,$00,$FE
EXPLOSIO3	DB	$58,$00,$FE

S57	DB	$DC,$81,$69,$0C,$10,$0C,$0A,$08,$06,$04,$02,$8C,$00
	DB	$FF

S58	DB	$DC,$81,$6D,$0C,$0D,$0E,$B0,$0F
	DB	$FF

MISCELLA2	DB	$8C,$59,$00,$FE
MISCELLB2	DB	$8C,$5A,$00,$FE
MISCELLC2	DB	$8C,$5B,$00,$FE

S59	DB	$DB,$90,$6A,$12,$FF
S5A	DB	$DB,$90,$6B,$0F,$FF
S5B	DB	$DB,$90,$6C,$0A,$FF
S5E
S5F
S60
S61
S62
S63
S64
S65
S66
S67
S68
S69
S6A
S6B
S6C
S6D
S6E
S6F
S70
S71
S72
S73
S74
S75
S76
S77
S78
S79
S7A
S7B
S7C
S7D
S7E
S7F
	DB	$F0,$FF




CLEARAUD		DB	$00,$FE					;EMPTY SFX
S00		DB	$E1,$FF
SEX


;----------------------------------------------------------------
; Interrupt Vector Table
;----------------------------------------------------------------
 
 .org $FFFA

 .dw NMI
 .dw RESETVECTOR
 .dw IRQ

;----------------------------------------------------------------
; EOF
;----------------------------------------------------------------